from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Devices.WiFi
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Networking.Connectivity
import win32more.Windows.Security.Credentials
import win32more.Windows.Win32.System.WinRT
class IWiFiAdapter(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.WiFi.IWiFiAdapter'
    _iid_ = Guid('{a6c4e423-3d75-43a4-b9de-11e26b72d9b0}')
    @winrt_commethod(6)
    def get_NetworkAdapter(self) -> win32more.Windows.Networking.Connectivity.NetworkAdapter: ...
    @winrt_commethod(7)
    def ScanAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(8)
    def get_NetworkReport(self) -> win32more.Windows.Devices.WiFi.WiFiNetworkReport: ...
    @winrt_commethod(9)
    def add_AvailableNetworksChanged(self, args: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Devices.WiFi.WiFiAdapter, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(10)
    def remove_AvailableNetworksChanged(self, eventCookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(11)
    def ConnectAsync(self, availableNetwork: win32more.Windows.Devices.WiFi.WiFiAvailableNetwork, reconnectionKind: win32more.Windows.Devices.WiFi.WiFiReconnectionKind) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.WiFi.WiFiConnectionResult]: ...
    @winrt_commethod(12)
    def ConnectWithPasswordCredentialAsync(self, availableNetwork: win32more.Windows.Devices.WiFi.WiFiAvailableNetwork, reconnectionKind: win32more.Windows.Devices.WiFi.WiFiReconnectionKind, passwordCredential: win32more.Windows.Security.Credentials.PasswordCredential) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.WiFi.WiFiConnectionResult]: ...
    @winrt_commethod(13)
    def ConnectWithPasswordCredentialAndSsidAsync(self, availableNetwork: win32more.Windows.Devices.WiFi.WiFiAvailableNetwork, reconnectionKind: win32more.Windows.Devices.WiFi.WiFiReconnectionKind, passwordCredential: win32more.Windows.Security.Credentials.PasswordCredential, ssid: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.WiFi.WiFiConnectionResult]: ...
    @winrt_commethod(14)
    def Disconnect(self) -> Void: ...
    NetworkAdapter = property(get_NetworkAdapter, None)
    NetworkReport = property(get_NetworkReport, None)
    AvailableNetworksChanged = event()
class IWiFiAdapter2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.WiFi.IWiFiAdapter2'
    _iid_ = Guid('{5bc4501d-81e4-453d-9430-1fcafbadd6b6}')
    @winrt_commethod(6)
    def GetWpsConfigurationAsync(self, availableNetwork: win32more.Windows.Devices.WiFi.WiFiAvailableNetwork) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.WiFi.WiFiWpsConfigurationResult]: ...
    @winrt_commethod(7)
    def ConnectWithPasswordCredentialAndSsidAndConnectionMethodAsync(self, availableNetwork: win32more.Windows.Devices.WiFi.WiFiAvailableNetwork, reconnectionKind: win32more.Windows.Devices.WiFi.WiFiReconnectionKind, passwordCredential: win32more.Windows.Security.Credentials.PasswordCredential, ssid: WinRT_String, connectionMethod: win32more.Windows.Devices.WiFi.WiFiConnectionMethod) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.WiFi.WiFiConnectionResult]: ...
class IWiFiAdapterStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.WiFi.IWiFiAdapterStatics'
    _iid_ = Guid('{da25fddd-d24c-43e3-aabd-c4659f730f99}')
    @winrt_commethod(6)
    def FindAllAdaptersAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Devices.WiFi.WiFiAdapter]]: ...
    @winrt_commethod(7)
    def GetDeviceSelector(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def FromIdAsync(self, deviceId: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.WiFi.WiFiAdapter]: ...
    @winrt_commethod(9)
    def RequestAccessAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.WiFi.WiFiAccessStatus]: ...
class IWiFiAvailableNetwork(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.WiFi.IWiFiAvailableNetwork'
    _iid_ = Guid('{26e96246-183e-4704-9826-71b4a2f0f668}')
    @winrt_commethod(6)
    def get_Uptime(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(7)
    def get_Ssid(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_Bssid(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def get_ChannelCenterFrequencyInKilohertz(self) -> Int32: ...
    @winrt_commethod(10)
    def get_NetworkRssiInDecibelMilliwatts(self) -> Double: ...
    @winrt_commethod(11)
    def get_SignalBars(self) -> Byte: ...
    @winrt_commethod(12)
    def get_NetworkKind(self) -> win32more.Windows.Devices.WiFi.WiFiNetworkKind: ...
    @winrt_commethod(13)
    def get_PhyKind(self) -> win32more.Windows.Devices.WiFi.WiFiPhyKind: ...
    @winrt_commethod(14)
    def get_SecuritySettings(self) -> win32more.Windows.Networking.Connectivity.NetworkSecuritySettings: ...
    @winrt_commethod(15)
    def get_BeaconInterval(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(16)
    def get_IsWiFiDirect(self) -> Boolean: ...
    BeaconInterval = property(get_BeaconInterval, None)
    Bssid = property(get_Bssid, None)
    ChannelCenterFrequencyInKilohertz = property(get_ChannelCenterFrequencyInKilohertz, None)
    IsWiFiDirect = property(get_IsWiFiDirect, None)
    NetworkKind = property(get_NetworkKind, None)
    NetworkRssiInDecibelMilliwatts = property(get_NetworkRssiInDecibelMilliwatts, None)
    PhyKind = property(get_PhyKind, None)
    SecuritySettings = property(get_SecuritySettings, None)
    SignalBars = property(get_SignalBars, None)
    Ssid = property(get_Ssid, None)
    Uptime = property(get_Uptime, None)
class IWiFiConnectionResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.WiFi.IWiFiConnectionResult'
    _iid_ = Guid('{143bdfd9-c37d-40be-a5c8-857bce85a931}')
    @winrt_commethod(6)
    def get_ConnectionStatus(self) -> win32more.Windows.Devices.WiFi.WiFiConnectionStatus: ...
    ConnectionStatus = property(get_ConnectionStatus, None)
class IWiFiNetworkReport(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.WiFi.IWiFiNetworkReport'
    _iid_ = Guid('{9524ded2-5911-445e-8194-be4f1a704895}')
    @winrt_commethod(6)
    def get_Timestamp(self) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_commethod(7)
    def get_AvailableNetworks(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Devices.WiFi.WiFiAvailableNetwork]: ...
    AvailableNetworks = property(get_AvailableNetworks, None)
    Timestamp = property(get_Timestamp, None)
class IWiFiOnDemandHotspotConnectTriggerDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.WiFi.IWiFiOnDemandHotspotConnectTriggerDetails'
    _iid_ = Guid('{a268eb58-68f5-59cf-8d38-35bf44b097ef}')
    @winrt_commethod(6)
    def get_RequestedNetwork(self) -> win32more.Windows.Devices.WiFi.WiFiOnDemandHotspotNetwork: ...
    @winrt_commethod(7)
    def ReportError(self, status: win32more.Windows.Devices.WiFi.WiFiOnDemandHotspotConnectStatus) -> Void: ...
    @winrt_commethod(8)
    def ConnectAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.WiFi.WiFiOnDemandHotspotConnectionResult]: ...
    @winrt_commethod(9)
    def Connect(self) -> win32more.Windows.Devices.WiFi.WiFiOnDemandHotspotConnectionResult: ...
    RequestedNetwork = property(get_RequestedNetwork, None)
class IWiFiOnDemandHotspotConnectionResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.WiFi.IWiFiOnDemandHotspotConnectionResult'
    _iid_ = Guid('{911794a1-6c82-5de3-8a4a-f9ff22a4957a}')
    @winrt_commethod(6)
    def get_Status(self) -> win32more.Windows.Devices.WiFi.WiFiOnDemandHotspotConnectStatus: ...
    Status = property(get_Status, None)
class IWiFiOnDemandHotspotNetwork(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.WiFi.IWiFiOnDemandHotspotNetwork'
    _iid_ = Guid('{18dc7115-a04e-507c-bbaf-b78369d29fa7}')
    @winrt_commethod(6)
    def GetProperties(self) -> win32more.Windows.Devices.WiFi.WiFiOnDemandHotspotNetworkProperties: ...
    @winrt_commethod(7)
    def UpdateProperties(self, newProperties: win32more.Windows.Devices.WiFi.WiFiOnDemandHotspotNetworkProperties) -> Void: ...
    @winrt_commethod(8)
    def get_Id(self) -> Guid: ...
    Id = property(get_Id, None)
class IWiFiOnDemandHotspotNetworkProperties(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.WiFi.IWiFiOnDemandHotspotNetworkProperties'
    _iid_ = Guid('{c810a1f2-c81d-5852-be50-e4bd4d81e98d}')
    @winrt_commethod(6)
    def get_DisplayName(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_DisplayName(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def get_Availability(self) -> win32more.Windows.Devices.WiFi.WiFiOnDemandHotspotAvailability: ...
    @winrt_commethod(9)
    def put_Availability(self, value: win32more.Windows.Devices.WiFi.WiFiOnDemandHotspotAvailability) -> Void: ...
    @winrt_commethod(10)
    def get_RemainingBatteryPercent(self) -> win32more.Windows.Foundation.IReference[UInt32]: ...
    @winrt_commethod(11)
    def put_RemainingBatteryPercent(self, value: win32more.Windows.Foundation.IReference[UInt32]) -> Void: ...
    @winrt_commethod(12)
    def get_CellularBars(self) -> win32more.Windows.Foundation.IReference[win32more.Windows.Devices.WiFi.WiFiOnDemandHotspotCellularBars]: ...
    @winrt_commethod(13)
    def put_CellularBars(self, value: win32more.Windows.Foundation.IReference[win32more.Windows.Devices.WiFi.WiFiOnDemandHotspotCellularBars]) -> Void: ...
    @winrt_commethod(14)
    def get_IsMetered(self) -> Boolean: ...
    @winrt_commethod(15)
    def put_IsMetered(self, value: Boolean) -> Void: ...
    @winrt_commethod(16)
    def get_Ssid(self) -> WinRT_String: ...
    @winrt_commethod(17)
    def put_Ssid(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(18)
    def get_Password(self) -> win32more.Windows.Security.Credentials.PasswordCredential: ...
    @winrt_commethod(19)
    def put_Password(self, value: win32more.Windows.Security.Credentials.PasswordCredential) -> Void: ...
    Availability = property(get_Availability, put_Availability)
    CellularBars = property(get_CellularBars, put_CellularBars)
    DisplayName = property(get_DisplayName, put_DisplayName)
    IsMetered = property(get_IsMetered, put_IsMetered)
    Password = property(get_Password, put_Password)
    RemainingBatteryPercent = property(get_RemainingBatteryPercent, put_RemainingBatteryPercent)
    Ssid = property(get_Ssid, put_Ssid)
class IWiFiOnDemandHotspotNetworkStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.WiFi.IWiFiOnDemandHotspotNetworkStatics'
    _iid_ = Guid('{00f5b8ac-80e7-5054-871c-8739f374e3c9}')
    @winrt_commethod(6)
    def GetOrCreateById(self, networkId: Guid) -> win32more.Windows.Devices.WiFi.WiFiOnDemandHotspotNetwork: ...
class IWiFiWpsConfigurationResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.WiFi.IWiFiWpsConfigurationResult'
    _iid_ = Guid('{67b49871-17ee-42d1-b14f-5a11f1226fb5}')
    @winrt_commethod(6)
    def get_Status(self) -> win32more.Windows.Devices.WiFi.WiFiWpsConfigurationStatus: ...
    @winrt_commethod(7)
    def get_SupportedWpsKinds(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Devices.WiFi.WiFiWpsKind]: ...
    Status = property(get_Status, None)
    SupportedWpsKinds = property(get_SupportedWpsKinds, None)
class WiFiAccessStatus(Enum, Int32):
    Unspecified = 0
    Allowed = 1
    DeniedByUser = 2
    DeniedBySystem = 3
class WiFiAdapter(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.WiFi.IWiFiAdapter
    _classid_ = 'Windows.Devices.WiFi.WiFiAdapter'
    @winrt_mixinmethod
    def get_NetworkAdapter(self: win32more.Windows.Devices.WiFi.IWiFiAdapter) -> win32more.Windows.Networking.Connectivity.NetworkAdapter: ...
    @winrt_mixinmethod
    def ScanAsync(self: win32more.Windows.Devices.WiFi.IWiFiAdapter) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def get_NetworkReport(self: win32more.Windows.Devices.WiFi.IWiFiAdapter) -> win32more.Windows.Devices.WiFi.WiFiNetworkReport: ...
    @winrt_mixinmethod
    def add_AvailableNetworksChanged(self: win32more.Windows.Devices.WiFi.IWiFiAdapter, args: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Devices.WiFi.WiFiAdapter, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_AvailableNetworksChanged(self: win32more.Windows.Devices.WiFi.IWiFiAdapter, eventCookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def ConnectAsync(self: win32more.Windows.Devices.WiFi.IWiFiAdapter, availableNetwork: win32more.Windows.Devices.WiFi.WiFiAvailableNetwork, reconnectionKind: win32more.Windows.Devices.WiFi.WiFiReconnectionKind) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.WiFi.WiFiConnectionResult]: ...
    @winrt_mixinmethod
    def ConnectWithPasswordCredentialAsync(self: win32more.Windows.Devices.WiFi.IWiFiAdapter, availableNetwork: win32more.Windows.Devices.WiFi.WiFiAvailableNetwork, reconnectionKind: win32more.Windows.Devices.WiFi.WiFiReconnectionKind, passwordCredential: win32more.Windows.Security.Credentials.PasswordCredential) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.WiFi.WiFiConnectionResult]: ...
    @winrt_mixinmethod
    def ConnectWithPasswordCredentialAndSsidAsync(self: win32more.Windows.Devices.WiFi.IWiFiAdapter, availableNetwork: win32more.Windows.Devices.WiFi.WiFiAvailableNetwork, reconnectionKind: win32more.Windows.Devices.WiFi.WiFiReconnectionKind, passwordCredential: win32more.Windows.Security.Credentials.PasswordCredential, ssid: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.WiFi.WiFiConnectionResult]: ...
    @winrt_mixinmethod
    def Disconnect(self: win32more.Windows.Devices.WiFi.IWiFiAdapter) -> Void: ...
    @winrt_mixinmethod
    def GetWpsConfigurationAsync(self: win32more.Windows.Devices.WiFi.IWiFiAdapter2, availableNetwork: win32more.Windows.Devices.WiFi.WiFiAvailableNetwork) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.WiFi.WiFiWpsConfigurationResult]: ...
    @winrt_mixinmethod
    def ConnectWithPasswordCredentialAndSsidAndConnectionMethodAsync(self: win32more.Windows.Devices.WiFi.IWiFiAdapter2, availableNetwork: win32more.Windows.Devices.WiFi.WiFiAvailableNetwork, reconnectionKind: win32more.Windows.Devices.WiFi.WiFiReconnectionKind, passwordCredential: win32more.Windows.Security.Credentials.PasswordCredential, ssid: WinRT_String, connectionMethod: win32more.Windows.Devices.WiFi.WiFiConnectionMethod) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.WiFi.WiFiConnectionResult]: ...
    @winrt_classmethod
    def FindAllAdaptersAsync(cls: win32more.Windows.Devices.WiFi.IWiFiAdapterStatics) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Devices.WiFi.WiFiAdapter]]: ...
    @winrt_classmethod
    def GetDeviceSelector(cls: win32more.Windows.Devices.WiFi.IWiFiAdapterStatics) -> WinRT_String: ...
    @winrt_classmethod
    def FromIdAsync(cls: win32more.Windows.Devices.WiFi.IWiFiAdapterStatics, deviceId: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.WiFi.WiFiAdapter]: ...
    @winrt_classmethod
    def RequestAccessAsync(cls: win32more.Windows.Devices.WiFi.IWiFiAdapterStatics) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.WiFi.WiFiAccessStatus]: ...
    NetworkAdapter = property(get_NetworkAdapter, None)
    NetworkReport = property(get_NetworkReport, None)
    AvailableNetworksChanged = event()
class WiFiAvailableNetwork(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.WiFi.IWiFiAvailableNetwork
    _classid_ = 'Windows.Devices.WiFi.WiFiAvailableNetwork'
    @winrt_mixinmethod
    def get_Uptime(self: win32more.Windows.Devices.WiFi.IWiFiAvailableNetwork) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_mixinmethod
    def get_Ssid(self: win32more.Windows.Devices.WiFi.IWiFiAvailableNetwork) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Bssid(self: win32more.Windows.Devices.WiFi.IWiFiAvailableNetwork) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_ChannelCenterFrequencyInKilohertz(self: win32more.Windows.Devices.WiFi.IWiFiAvailableNetwork) -> Int32: ...
    @winrt_mixinmethod
    def get_NetworkRssiInDecibelMilliwatts(self: win32more.Windows.Devices.WiFi.IWiFiAvailableNetwork) -> Double: ...
    @winrt_mixinmethod
    def get_SignalBars(self: win32more.Windows.Devices.WiFi.IWiFiAvailableNetwork) -> Byte: ...
    @winrt_mixinmethod
    def get_NetworkKind(self: win32more.Windows.Devices.WiFi.IWiFiAvailableNetwork) -> win32more.Windows.Devices.WiFi.WiFiNetworkKind: ...
    @winrt_mixinmethod
    def get_PhyKind(self: win32more.Windows.Devices.WiFi.IWiFiAvailableNetwork) -> win32more.Windows.Devices.WiFi.WiFiPhyKind: ...
    @winrt_mixinmethod
    def get_SecuritySettings(self: win32more.Windows.Devices.WiFi.IWiFiAvailableNetwork) -> win32more.Windows.Networking.Connectivity.NetworkSecuritySettings: ...
    @winrt_mixinmethod
    def get_BeaconInterval(self: win32more.Windows.Devices.WiFi.IWiFiAvailableNetwork) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_mixinmethod
    def get_IsWiFiDirect(self: win32more.Windows.Devices.WiFi.IWiFiAvailableNetwork) -> Boolean: ...
    BeaconInterval = property(get_BeaconInterval, None)
    Bssid = property(get_Bssid, None)
    ChannelCenterFrequencyInKilohertz = property(get_ChannelCenterFrequencyInKilohertz, None)
    IsWiFiDirect = property(get_IsWiFiDirect, None)
    NetworkKind = property(get_NetworkKind, None)
    NetworkRssiInDecibelMilliwatts = property(get_NetworkRssiInDecibelMilliwatts, None)
    PhyKind = property(get_PhyKind, None)
    SecuritySettings = property(get_SecuritySettings, None)
    SignalBars = property(get_SignalBars, None)
    Ssid = property(get_Ssid, None)
    Uptime = property(get_Uptime, None)
class WiFiConnectionMethod(Enum, Int32):
    Default = 0
    WpsPin = 1
    WpsPushButton = 2
class WiFiConnectionResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.WiFi.IWiFiConnectionResult
    _classid_ = 'Windows.Devices.WiFi.WiFiConnectionResult'
    @winrt_mixinmethod
    def get_ConnectionStatus(self: win32more.Windows.Devices.WiFi.IWiFiConnectionResult) -> win32more.Windows.Devices.WiFi.WiFiConnectionStatus: ...
    ConnectionStatus = property(get_ConnectionStatus, None)
class WiFiConnectionStatus(Enum, Int32):
    UnspecifiedFailure = 0
    Success = 1
    AccessRevoked = 2
    InvalidCredential = 3
    NetworkNotAvailable = 4
    Timeout = 5
    UnsupportedAuthenticationProtocol = 6
class WiFiNetworkKind(Enum, Int32):
    Any = 0
    Infrastructure = 1
    Adhoc = 2
class WiFiNetworkReport(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.WiFi.IWiFiNetworkReport
    _classid_ = 'Windows.Devices.WiFi.WiFiNetworkReport'
    @winrt_mixinmethod
    def get_Timestamp(self: win32more.Windows.Devices.WiFi.IWiFiNetworkReport) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_mixinmethod
    def get_AvailableNetworks(self: win32more.Windows.Devices.WiFi.IWiFiNetworkReport) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Devices.WiFi.WiFiAvailableNetwork]: ...
    AvailableNetworks = property(get_AvailableNetworks, None)
    Timestamp = property(get_Timestamp, None)
class WiFiOnDemandHotspotAvailability(Enum, Int32):
    Available = 0
    Unavailable = 1
class WiFiOnDemandHotspotCellularBars(Enum, Int32):
    ZeroBars = 0
    OneBar = 1
    TwoBars = 2
    ThreeBars = 3
    FourBars = 4
    FiveBars = 5
class WiFiOnDemandHotspotConnectStatus(Enum, Int32):
    UnspecifiedFailure = 0
    Success = 1
    AppTimedOut = 2
    InvalidCredential = 3
    NetworkNotAvailable = 4
    UnsupportedAuthenticationProtocol = 5
    BluetoothConnectFailed = 6
    BluetoothTransmissionError = 7
    OperationCanceledByUser = 8
    EntitlementCheckFailed = 9
    NoCellularSignal = 10
    CellularDataTurnedOff = 11
    WlanConnectFailed = 12
    WlanNotVisible = 13
    AccessPointCannotConnect = 14
    CellularConnectTimedOut = 15
    RoamingNotAllowed = 16
    PairingRequired = 17
    DataLimitReached = 18
class WiFiOnDemandHotspotConnectTriggerDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.WiFi.IWiFiOnDemandHotspotConnectTriggerDetails
    _classid_ = 'Windows.Devices.WiFi.WiFiOnDemandHotspotConnectTriggerDetails'
    @winrt_mixinmethod
    def get_RequestedNetwork(self: win32more.Windows.Devices.WiFi.IWiFiOnDemandHotspotConnectTriggerDetails) -> win32more.Windows.Devices.WiFi.WiFiOnDemandHotspotNetwork: ...
    @winrt_mixinmethod
    def ReportError(self: win32more.Windows.Devices.WiFi.IWiFiOnDemandHotspotConnectTriggerDetails, status: win32more.Windows.Devices.WiFi.WiFiOnDemandHotspotConnectStatus) -> Void: ...
    @winrt_mixinmethod
    def ConnectAsync(self: win32more.Windows.Devices.WiFi.IWiFiOnDemandHotspotConnectTriggerDetails) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.WiFi.WiFiOnDemandHotspotConnectionResult]: ...
    @winrt_mixinmethod
    def Connect(self: win32more.Windows.Devices.WiFi.IWiFiOnDemandHotspotConnectTriggerDetails) -> win32more.Windows.Devices.WiFi.WiFiOnDemandHotspotConnectionResult: ...
    RequestedNetwork = property(get_RequestedNetwork, None)
class WiFiOnDemandHotspotConnectionResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.WiFi.IWiFiOnDemandHotspotConnectionResult
    _classid_ = 'Windows.Devices.WiFi.WiFiOnDemandHotspotConnectionResult'
    @winrt_mixinmethod
    def get_Status(self: win32more.Windows.Devices.WiFi.IWiFiOnDemandHotspotConnectionResult) -> win32more.Windows.Devices.WiFi.WiFiOnDemandHotspotConnectStatus: ...
    Status = property(get_Status, None)
class WiFiOnDemandHotspotNetwork(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.WiFi.IWiFiOnDemandHotspotNetwork
    _classid_ = 'Windows.Devices.WiFi.WiFiOnDemandHotspotNetwork'
    @winrt_mixinmethod
    def GetProperties(self: win32more.Windows.Devices.WiFi.IWiFiOnDemandHotspotNetwork) -> win32more.Windows.Devices.WiFi.WiFiOnDemandHotspotNetworkProperties: ...
    @winrt_mixinmethod
    def UpdateProperties(self: win32more.Windows.Devices.WiFi.IWiFiOnDemandHotspotNetwork, newProperties: win32more.Windows.Devices.WiFi.WiFiOnDemandHotspotNetworkProperties) -> Void: ...
    @winrt_mixinmethod
    def get_Id(self: win32more.Windows.Devices.WiFi.IWiFiOnDemandHotspotNetwork) -> Guid: ...
    @winrt_classmethod
    def GetOrCreateById(cls: win32more.Windows.Devices.WiFi.IWiFiOnDemandHotspotNetworkStatics, networkId: Guid) -> win32more.Windows.Devices.WiFi.WiFiOnDemandHotspotNetwork: ...
    Id = property(get_Id, None)
class WiFiOnDemandHotspotNetworkProperties(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.WiFi.IWiFiOnDemandHotspotNetworkProperties
    _classid_ = 'Windows.Devices.WiFi.WiFiOnDemandHotspotNetworkProperties'
    @winrt_mixinmethod
    def get_DisplayName(self: win32more.Windows.Devices.WiFi.IWiFiOnDemandHotspotNetworkProperties) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_DisplayName(self: win32more.Windows.Devices.WiFi.IWiFiOnDemandHotspotNetworkProperties, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Availability(self: win32more.Windows.Devices.WiFi.IWiFiOnDemandHotspotNetworkProperties) -> win32more.Windows.Devices.WiFi.WiFiOnDemandHotspotAvailability: ...
    @winrt_mixinmethod
    def put_Availability(self: win32more.Windows.Devices.WiFi.IWiFiOnDemandHotspotNetworkProperties, value: win32more.Windows.Devices.WiFi.WiFiOnDemandHotspotAvailability) -> Void: ...
    @winrt_mixinmethod
    def get_RemainingBatteryPercent(self: win32more.Windows.Devices.WiFi.IWiFiOnDemandHotspotNetworkProperties) -> win32more.Windows.Foundation.IReference[UInt32]: ...
    @winrt_mixinmethod
    def put_RemainingBatteryPercent(self: win32more.Windows.Devices.WiFi.IWiFiOnDemandHotspotNetworkProperties, value: win32more.Windows.Foundation.IReference[UInt32]) -> Void: ...
    @winrt_mixinmethod
    def get_CellularBars(self: win32more.Windows.Devices.WiFi.IWiFiOnDemandHotspotNetworkProperties) -> win32more.Windows.Foundation.IReference[win32more.Windows.Devices.WiFi.WiFiOnDemandHotspotCellularBars]: ...
    @winrt_mixinmethod
    def put_CellularBars(self: win32more.Windows.Devices.WiFi.IWiFiOnDemandHotspotNetworkProperties, value: win32more.Windows.Foundation.IReference[win32more.Windows.Devices.WiFi.WiFiOnDemandHotspotCellularBars]) -> Void: ...
    @winrt_mixinmethod
    def get_IsMetered(self: win32more.Windows.Devices.WiFi.IWiFiOnDemandHotspotNetworkProperties) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsMetered(self: win32more.Windows.Devices.WiFi.IWiFiOnDemandHotspotNetworkProperties, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_Ssid(self: win32more.Windows.Devices.WiFi.IWiFiOnDemandHotspotNetworkProperties) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Ssid(self: win32more.Windows.Devices.WiFi.IWiFiOnDemandHotspotNetworkProperties, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Password(self: win32more.Windows.Devices.WiFi.IWiFiOnDemandHotspotNetworkProperties) -> win32more.Windows.Security.Credentials.PasswordCredential: ...
    @winrt_mixinmethod
    def put_Password(self: win32more.Windows.Devices.WiFi.IWiFiOnDemandHotspotNetworkProperties, value: win32more.Windows.Security.Credentials.PasswordCredential) -> Void: ...
    Availability = property(get_Availability, put_Availability)
    CellularBars = property(get_CellularBars, put_CellularBars)
    DisplayName = property(get_DisplayName, put_DisplayName)
    IsMetered = property(get_IsMetered, put_IsMetered)
    Password = property(get_Password, put_Password)
    RemainingBatteryPercent = property(get_RemainingBatteryPercent, put_RemainingBatteryPercent)
    Ssid = property(get_Ssid, put_Ssid)
class WiFiPhyKind(Enum, Int32):
    Unknown = 0
    Fhss = 1
    Dsss = 2
    IRBaseband = 3
    Ofdm = 4
    Hrdsss = 5
    Erp = 6
    HT = 7
    Vht = 8
    Dmg = 9
    HE = 10
    Eht = 11
class WiFiReconnectionKind(Enum, Int32):
    Automatic = 0
    Manual = 1
class WiFiWpsConfigurationResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.WiFi.IWiFiWpsConfigurationResult
    _classid_ = 'Windows.Devices.WiFi.WiFiWpsConfigurationResult'
    @winrt_mixinmethod
    def get_Status(self: win32more.Windows.Devices.WiFi.IWiFiWpsConfigurationResult) -> win32more.Windows.Devices.WiFi.WiFiWpsConfigurationStatus: ...
    @winrt_mixinmethod
    def get_SupportedWpsKinds(self: win32more.Windows.Devices.WiFi.IWiFiWpsConfigurationResult) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Devices.WiFi.WiFiWpsKind]: ...
    Status = property(get_Status, None)
    SupportedWpsKinds = property(get_SupportedWpsKinds, None)
class WiFiWpsConfigurationStatus(Enum, Int32):
    UnspecifiedFailure = 0
    Success = 1
    Timeout = 2
class WiFiWpsKind(Enum, Int32):
    Unknown = 0
    Pin = 1
    PushButton = 2
    Nfc = 3
    Ethernet = 4
    Usb = 5


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.UI.Input
import win32more.Windows.UI.Input.Preview
import win32more.Windows.UI.WindowManagement
import win32more.Windows.Win32.System.WinRT
class IInputActivationListenerPreviewStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Input.Preview.IInputActivationListenerPreviewStatics'
    _iid_ = Guid('{f0551ce5-0de6-5be0-a589-f737201a4582}')
    @winrt_commethod(6)
    def CreateForApplicationWindow(self, window: win32more.Windows.UI.WindowManagement.AppWindow) -> win32more.Windows.UI.Input.InputActivationListener: ...
class InputActivationListenerPreview(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Input.Preview.InputActivationListenerPreview'
    @winrt_classmethod
    def CreateForApplicationWindow(cls: win32more.Windows.UI.Input.Preview.IInputActivationListenerPreviewStatics, window: win32more.Windows.UI.WindowManagement.AppWindow) -> win32more.Windows.UI.Input.InputActivationListener: ...


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Foundation.Numerics
import win32more.Windows.Media.Devices.Core
import win32more.Windows.Media.MediaProperties
import win32more.Windows.Perception.Spatial
import win32more.Windows.Win32.System.WinRT
class CameraIntrinsics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.Devices.Core.ICameraIntrinsics
    _classid_ = 'Windows.Media.Devices.Core.CameraIntrinsics'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 6:
            super().__init__(move=win32more.Windows.Media.Devices.Core.CameraIntrinsics.Create(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def Create(cls: win32more.Windows.Media.Devices.Core.ICameraIntrinsicsFactory, focalLength: win32more.Windows.Foundation.Numerics.Vector2, principalPoint: win32more.Windows.Foundation.Numerics.Vector2, radialDistortion: win32more.Windows.Foundation.Numerics.Vector3, tangentialDistortion: win32more.Windows.Foundation.Numerics.Vector2, imageWidth: UInt32, imageHeight: UInt32) -> win32more.Windows.Media.Devices.Core.CameraIntrinsics: ...
    @winrt_mixinmethod
    def get_FocalLength(self: win32more.Windows.Media.Devices.Core.ICameraIntrinsics) -> win32more.Windows.Foundation.Numerics.Vector2: ...
    @winrt_mixinmethod
    def get_PrincipalPoint(self: win32more.Windows.Media.Devices.Core.ICameraIntrinsics) -> win32more.Windows.Foundation.Numerics.Vector2: ...
    @winrt_mixinmethod
    def get_RadialDistortion(self: win32more.Windows.Media.Devices.Core.ICameraIntrinsics) -> win32more.Windows.Foundation.Numerics.Vector3: ...
    @winrt_mixinmethod
    def get_TangentialDistortion(self: win32more.Windows.Media.Devices.Core.ICameraIntrinsics) -> win32more.Windows.Foundation.Numerics.Vector2: ...
    @winrt_mixinmethod
    def get_ImageWidth(self: win32more.Windows.Media.Devices.Core.ICameraIntrinsics) -> UInt32: ...
    @winrt_mixinmethod
    def get_ImageHeight(self: win32more.Windows.Media.Devices.Core.ICameraIntrinsics) -> UInt32: ...
    @winrt_mixinmethod
    def ProjectOntoFrame(self: win32more.Windows.Media.Devices.Core.ICameraIntrinsics, coordinate: win32more.Windows.Foundation.Numerics.Vector3) -> win32more.Windows.Foundation.Point: ...
    @winrt_mixinmethod
    def UnprojectAtUnitDepth(self: win32more.Windows.Media.Devices.Core.ICameraIntrinsics, pixelCoordinate: win32more.Windows.Foundation.Point) -> win32more.Windows.Foundation.Numerics.Vector2: ...
    @winrt_mixinmethod
    def ProjectManyOntoFrame(self: win32more.Windows.Media.Devices.Core.ICameraIntrinsics, coordinates: PassArray[win32more.Windows.Foundation.Numerics.Vector3], results: FillArray[win32more.Windows.Foundation.Point]) -> Void: ...
    @winrt_mixinmethod
    def UnprojectPixelsAtUnitDepth(self: win32more.Windows.Media.Devices.Core.ICameraIntrinsics, pixelCoordinates: PassArray[win32more.Windows.Foundation.Point], results: FillArray[win32more.Windows.Foundation.Numerics.Vector2]) -> Void: ...
    @winrt_mixinmethod
    def get_UndistortedProjectionTransform(self: win32more.Windows.Media.Devices.Core.ICameraIntrinsics2) -> win32more.Windows.Foundation.Numerics.Matrix4x4: ...
    @winrt_mixinmethod
    def DistortPoint(self: win32more.Windows.Media.Devices.Core.ICameraIntrinsics2, input: win32more.Windows.Foundation.Point) -> win32more.Windows.Foundation.Point: ...
    @winrt_mixinmethod
    def DistortPoints(self: win32more.Windows.Media.Devices.Core.ICameraIntrinsics2, inputs: PassArray[win32more.Windows.Foundation.Point], results: FillArray[win32more.Windows.Foundation.Point]) -> Void: ...
    @winrt_mixinmethod
    def UndistortPoint(self: win32more.Windows.Media.Devices.Core.ICameraIntrinsics2, input: win32more.Windows.Foundation.Point) -> win32more.Windows.Foundation.Point: ...
    @winrt_mixinmethod
    def UndistortPoints(self: win32more.Windows.Media.Devices.Core.ICameraIntrinsics2, inputs: PassArray[win32more.Windows.Foundation.Point], results: FillArray[win32more.Windows.Foundation.Point]) -> Void: ...
    FocalLength = property(get_FocalLength, None)
    ImageHeight = property(get_ImageHeight, None)
    ImageWidth = property(get_ImageWidth, None)
    PrincipalPoint = property(get_PrincipalPoint, None)
    RadialDistortion = property(get_RadialDistortion, None)
    TangentialDistortion = property(get_TangentialDistortion, None)
    UndistortedProjectionTransform = property(get_UndistortedProjectionTransform, None)
class DepthCorrelatedCoordinateMapper(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[ContextManagerProtocol]
    default_interface: win32more.Windows.Media.Devices.Core.IDepthCorrelatedCoordinateMapper
    _classid_ = 'Windows.Media.Devices.Core.DepthCorrelatedCoordinateMapper'
    @winrt_mixinmethod
    def UnprojectPoint(self: win32more.Windows.Media.Devices.Core.IDepthCorrelatedCoordinateMapper, sourcePoint: win32more.Windows.Foundation.Point, targetCoordinateSystem: win32more.Windows.Perception.Spatial.SpatialCoordinateSystem) -> win32more.Windows.Foundation.Numerics.Vector3: ...
    @winrt_mixinmethod
    def UnprojectPoints(self: win32more.Windows.Media.Devices.Core.IDepthCorrelatedCoordinateMapper, sourcePoints: PassArray[win32more.Windows.Foundation.Point], targetCoordinateSystem: win32more.Windows.Perception.Spatial.SpatialCoordinateSystem, results: FillArray[win32more.Windows.Foundation.Numerics.Vector3]) -> Void: ...
    @winrt_mixinmethod
    def MapPoint(self: win32more.Windows.Media.Devices.Core.IDepthCorrelatedCoordinateMapper, sourcePoint: win32more.Windows.Foundation.Point, targetCoordinateSystem: win32more.Windows.Perception.Spatial.SpatialCoordinateSystem, targetCameraIntrinsics: win32more.Windows.Media.Devices.Core.CameraIntrinsics) -> win32more.Windows.Foundation.Point: ...
    @winrt_mixinmethod
    def MapPoints(self: win32more.Windows.Media.Devices.Core.IDepthCorrelatedCoordinateMapper, sourcePoints: PassArray[win32more.Windows.Foundation.Point], targetCoordinateSystem: win32more.Windows.Perception.Spatial.SpatialCoordinateSystem, targetCameraIntrinsics: win32more.Windows.Media.Devices.Core.CameraIntrinsics, results: FillArray[win32more.Windows.Foundation.Point]) -> Void: ...
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Foundation.IClosable) -> Void: ...
class FrameControlCapabilities(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.Devices.Core.IFrameControlCapabilities
    _classid_ = 'Windows.Media.Devices.Core.FrameControlCapabilities'
    @winrt_mixinmethod
    def get_Exposure(self: win32more.Windows.Media.Devices.Core.IFrameControlCapabilities) -> win32more.Windows.Media.Devices.Core.FrameExposureCapabilities: ...
    @winrt_mixinmethod
    def get_ExposureCompensation(self: win32more.Windows.Media.Devices.Core.IFrameControlCapabilities) -> win32more.Windows.Media.Devices.Core.FrameExposureCompensationCapabilities: ...
    @winrt_mixinmethod
    def get_IsoSpeed(self: win32more.Windows.Media.Devices.Core.IFrameControlCapabilities) -> win32more.Windows.Media.Devices.Core.FrameIsoSpeedCapabilities: ...
    @winrt_mixinmethod
    def get_Focus(self: win32more.Windows.Media.Devices.Core.IFrameControlCapabilities) -> win32more.Windows.Media.Devices.Core.FrameFocusCapabilities: ...
    @winrt_mixinmethod
    def get_PhotoConfirmationSupported(self: win32more.Windows.Media.Devices.Core.IFrameControlCapabilities) -> Boolean: ...
    @winrt_mixinmethod
    def get_Flash(self: win32more.Windows.Media.Devices.Core.IFrameControlCapabilities2) -> win32more.Windows.Media.Devices.Core.FrameFlashCapabilities: ...
    Exposure = property(get_Exposure, None)
    ExposureCompensation = property(get_ExposureCompensation, None)
    Flash = property(get_Flash, None)
    Focus = property(get_Focus, None)
    IsoSpeed = property(get_IsoSpeed, None)
    PhotoConfirmationSupported = property(get_PhotoConfirmationSupported, None)
class FrameController(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.Devices.Core.IFrameController
    _classid_ = 'Windows.Media.Devices.Core.FrameController'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.Media.Devices.Core.FrameController.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.Media.Devices.Core.FrameController: ...
    @winrt_mixinmethod
    def get_ExposureControl(self: win32more.Windows.Media.Devices.Core.IFrameController) -> win32more.Windows.Media.Devices.Core.FrameExposureControl: ...
    @winrt_mixinmethod
    def get_ExposureCompensationControl(self: win32more.Windows.Media.Devices.Core.IFrameController) -> win32more.Windows.Media.Devices.Core.FrameExposureCompensationControl: ...
    @winrt_mixinmethod
    def get_IsoSpeedControl(self: win32more.Windows.Media.Devices.Core.IFrameController) -> win32more.Windows.Media.Devices.Core.FrameIsoSpeedControl: ...
    @winrt_mixinmethod
    def get_FocusControl(self: win32more.Windows.Media.Devices.Core.IFrameController) -> win32more.Windows.Media.Devices.Core.FrameFocusControl: ...
    @winrt_mixinmethod
    def get_PhotoConfirmationEnabled(self: win32more.Windows.Media.Devices.Core.IFrameController) -> win32more.Windows.Foundation.IReference[Boolean]: ...
    @winrt_mixinmethod
    def put_PhotoConfirmationEnabled(self: win32more.Windows.Media.Devices.Core.IFrameController, value: win32more.Windows.Foundation.IReference[Boolean]) -> Void: ...
    @winrt_mixinmethod
    def get_FlashControl(self: win32more.Windows.Media.Devices.Core.IFrameController2) -> win32more.Windows.Media.Devices.Core.FrameFlashControl: ...
    ExposureCompensationControl = property(get_ExposureCompensationControl, None)
    ExposureControl = property(get_ExposureControl, None)
    FlashControl = property(get_FlashControl, None)
    FocusControl = property(get_FocusControl, None)
    IsoSpeedControl = property(get_IsoSpeedControl, None)
    PhotoConfirmationEnabled = property(get_PhotoConfirmationEnabled, put_PhotoConfirmationEnabled)
class FrameExposureCapabilities(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.Devices.Core.IFrameExposureCapabilities
    _classid_ = 'Windows.Media.Devices.Core.FrameExposureCapabilities'
    @winrt_mixinmethod
    def get_Supported(self: win32more.Windows.Media.Devices.Core.IFrameExposureCapabilities) -> Boolean: ...
    @winrt_mixinmethod
    def get_Min(self: win32more.Windows.Media.Devices.Core.IFrameExposureCapabilities) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_mixinmethod
    def get_Max(self: win32more.Windows.Media.Devices.Core.IFrameExposureCapabilities) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_mixinmethod
    def get_Step(self: win32more.Windows.Media.Devices.Core.IFrameExposureCapabilities) -> win32more.Windows.Foundation.TimeSpan: ...
    Max = property(get_Max, None)
    Min = property(get_Min, None)
    Step = property(get_Step, None)
    Supported = property(get_Supported, None)
class FrameExposureCompensationCapabilities(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.Devices.Core.IFrameExposureCompensationCapabilities
    _classid_ = 'Windows.Media.Devices.Core.FrameExposureCompensationCapabilities'
    @winrt_mixinmethod
    def get_Supported(self: win32more.Windows.Media.Devices.Core.IFrameExposureCompensationCapabilities) -> Boolean: ...
    @winrt_mixinmethod
    def get_Min(self: win32more.Windows.Media.Devices.Core.IFrameExposureCompensationCapabilities) -> Single: ...
    @winrt_mixinmethod
    def get_Max(self: win32more.Windows.Media.Devices.Core.IFrameExposureCompensationCapabilities) -> Single: ...
    @winrt_mixinmethod
    def get_Step(self: win32more.Windows.Media.Devices.Core.IFrameExposureCompensationCapabilities) -> Single: ...
    Max = property(get_Max, None)
    Min = property(get_Min, None)
    Step = property(get_Step, None)
    Supported = property(get_Supported, None)
class FrameExposureCompensationControl(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.Devices.Core.IFrameExposureCompensationControl
    _classid_ = 'Windows.Media.Devices.Core.FrameExposureCompensationControl'
    @winrt_mixinmethod
    def get_Value(self: win32more.Windows.Media.Devices.Core.IFrameExposureCompensationControl) -> win32more.Windows.Foundation.IReference[Single]: ...
    @winrt_mixinmethod
    def put_Value(self: win32more.Windows.Media.Devices.Core.IFrameExposureCompensationControl, value: win32more.Windows.Foundation.IReference[Single]) -> Void: ...
    Value = property(get_Value, put_Value)
class FrameExposureControl(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.Devices.Core.IFrameExposureControl
    _classid_ = 'Windows.Media.Devices.Core.FrameExposureControl'
    @winrt_mixinmethod
    def get_Auto(self: win32more.Windows.Media.Devices.Core.IFrameExposureControl) -> Boolean: ...
    @winrt_mixinmethod
    def put_Auto(self: win32more.Windows.Media.Devices.Core.IFrameExposureControl, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_Value(self: win32more.Windows.Media.Devices.Core.IFrameExposureControl) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.TimeSpan]: ...
    @winrt_mixinmethod
    def put_Value(self: win32more.Windows.Media.Devices.Core.IFrameExposureControl, value: win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.TimeSpan]) -> Void: ...
    Auto = property(get_Auto, put_Auto)
    Value = property(get_Value, put_Value)
class FrameFlashCapabilities(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.Devices.Core.IFrameFlashCapabilities
    _classid_ = 'Windows.Media.Devices.Core.FrameFlashCapabilities'
    @winrt_mixinmethod
    def get_Supported(self: win32more.Windows.Media.Devices.Core.IFrameFlashCapabilities) -> Boolean: ...
    @winrt_mixinmethod
    def get_RedEyeReductionSupported(self: win32more.Windows.Media.Devices.Core.IFrameFlashCapabilities) -> Boolean: ...
    @winrt_mixinmethod
    def get_PowerSupported(self: win32more.Windows.Media.Devices.Core.IFrameFlashCapabilities) -> Boolean: ...
    PowerSupported = property(get_PowerSupported, None)
    RedEyeReductionSupported = property(get_RedEyeReductionSupported, None)
    Supported = property(get_Supported, None)
class FrameFlashControl(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.Devices.Core.IFrameFlashControl
    _classid_ = 'Windows.Media.Devices.Core.FrameFlashControl'
    @winrt_mixinmethod
    def get_Mode(self: win32more.Windows.Media.Devices.Core.IFrameFlashControl) -> win32more.Windows.Media.Devices.Core.FrameFlashMode: ...
    @winrt_mixinmethod
    def put_Mode(self: win32more.Windows.Media.Devices.Core.IFrameFlashControl, value: win32more.Windows.Media.Devices.Core.FrameFlashMode) -> Void: ...
    @winrt_mixinmethod
    def get_Auto(self: win32more.Windows.Media.Devices.Core.IFrameFlashControl) -> Boolean: ...
    @winrt_mixinmethod
    def put_Auto(self: win32more.Windows.Media.Devices.Core.IFrameFlashControl, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_RedEyeReduction(self: win32more.Windows.Media.Devices.Core.IFrameFlashControl) -> Boolean: ...
    @winrt_mixinmethod
    def put_RedEyeReduction(self: win32more.Windows.Media.Devices.Core.IFrameFlashControl, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_PowerPercent(self: win32more.Windows.Media.Devices.Core.IFrameFlashControl) -> Single: ...
    @winrt_mixinmethod
    def put_PowerPercent(self: win32more.Windows.Media.Devices.Core.IFrameFlashControl, value: Single) -> Void: ...
    Auto = property(get_Auto, put_Auto)
    Mode = property(get_Mode, put_Mode)
    PowerPercent = property(get_PowerPercent, put_PowerPercent)
    RedEyeReduction = property(get_RedEyeReduction, put_RedEyeReduction)
class FrameFlashMode(Enum, Int32):
    Disable = 0
    Enable = 1
    Global = 2
class FrameFocusCapabilities(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.Devices.Core.IFrameFocusCapabilities
    _classid_ = 'Windows.Media.Devices.Core.FrameFocusCapabilities'
    @winrt_mixinmethod
    def get_Supported(self: win32more.Windows.Media.Devices.Core.IFrameFocusCapabilities) -> Boolean: ...
    @winrt_mixinmethod
    def get_Min(self: win32more.Windows.Media.Devices.Core.IFrameFocusCapabilities) -> UInt32: ...
    @winrt_mixinmethod
    def get_Max(self: win32more.Windows.Media.Devices.Core.IFrameFocusCapabilities) -> UInt32: ...
    @winrt_mixinmethod
    def get_Step(self: win32more.Windows.Media.Devices.Core.IFrameFocusCapabilities) -> UInt32: ...
    Max = property(get_Max, None)
    Min = property(get_Min, None)
    Step = property(get_Step, None)
    Supported = property(get_Supported, None)
class FrameFocusControl(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.Devices.Core.IFrameFocusControl
    _classid_ = 'Windows.Media.Devices.Core.FrameFocusControl'
    @winrt_mixinmethod
    def get_Value(self: win32more.Windows.Media.Devices.Core.IFrameFocusControl) -> win32more.Windows.Foundation.IReference[UInt32]: ...
    @winrt_mixinmethod
    def put_Value(self: win32more.Windows.Media.Devices.Core.IFrameFocusControl, value: win32more.Windows.Foundation.IReference[UInt32]) -> Void: ...
    Value = property(get_Value, put_Value)
class FrameIsoSpeedCapabilities(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.Devices.Core.IFrameIsoSpeedCapabilities
    _classid_ = 'Windows.Media.Devices.Core.FrameIsoSpeedCapabilities'
    @winrt_mixinmethod
    def get_Supported(self: win32more.Windows.Media.Devices.Core.IFrameIsoSpeedCapabilities) -> Boolean: ...
    @winrt_mixinmethod
    def get_Min(self: win32more.Windows.Media.Devices.Core.IFrameIsoSpeedCapabilities) -> UInt32: ...
    @winrt_mixinmethod
    def get_Max(self: win32more.Windows.Media.Devices.Core.IFrameIsoSpeedCapabilities) -> UInt32: ...
    @winrt_mixinmethod
    def get_Step(self: win32more.Windows.Media.Devices.Core.IFrameIsoSpeedCapabilities) -> UInt32: ...
    Max = property(get_Max, None)
    Min = property(get_Min, None)
    Step = property(get_Step, None)
    Supported = property(get_Supported, None)
class FrameIsoSpeedControl(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.Devices.Core.IFrameIsoSpeedControl
    _classid_ = 'Windows.Media.Devices.Core.FrameIsoSpeedControl'
    @winrt_mixinmethod
    def get_Auto(self: win32more.Windows.Media.Devices.Core.IFrameIsoSpeedControl) -> Boolean: ...
    @winrt_mixinmethod
    def put_Auto(self: win32more.Windows.Media.Devices.Core.IFrameIsoSpeedControl, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_Value(self: win32more.Windows.Media.Devices.Core.IFrameIsoSpeedControl) -> win32more.Windows.Foundation.IReference[UInt32]: ...
    @winrt_mixinmethod
    def put_Value(self: win32more.Windows.Media.Devices.Core.IFrameIsoSpeedControl, value: win32more.Windows.Foundation.IReference[UInt32]) -> Void: ...
    Auto = property(get_Auto, put_Auto)
    Value = property(get_Value, put_Value)
class ICameraIntrinsics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Devices.Core.ICameraIntrinsics'
    _iid_ = Guid('{0aa6ed32-6589-49da-afde-594270ca0aac}')
    @winrt_commethod(6)
    def get_FocalLength(self) -> win32more.Windows.Foundation.Numerics.Vector2: ...
    @winrt_commethod(7)
    def get_PrincipalPoint(self) -> win32more.Windows.Foundation.Numerics.Vector2: ...
    @winrt_commethod(8)
    def get_RadialDistortion(self) -> win32more.Windows.Foundation.Numerics.Vector3: ...
    @winrt_commethod(9)
    def get_TangentialDistortion(self) -> win32more.Windows.Foundation.Numerics.Vector2: ...
    @winrt_commethod(10)
    def get_ImageWidth(self) -> UInt32: ...
    @winrt_commethod(11)
    def get_ImageHeight(self) -> UInt32: ...
    @winrt_commethod(12)
    def ProjectOntoFrame(self, coordinate: win32more.Windows.Foundation.Numerics.Vector3) -> win32more.Windows.Foundation.Point: ...
    @winrt_commethod(13)
    def UnprojectAtUnitDepth(self, pixelCoordinate: win32more.Windows.Foundation.Point) -> win32more.Windows.Foundation.Numerics.Vector2: ...
    @winrt_commethod(14)
    def ProjectManyOntoFrame(self, coordinates: PassArray[win32more.Windows.Foundation.Numerics.Vector3], results: FillArray[win32more.Windows.Foundation.Point]) -> Void: ...
    @winrt_commethod(15)
    def UnprojectPixelsAtUnitDepth(self, pixelCoordinates: PassArray[win32more.Windows.Foundation.Point], results: FillArray[win32more.Windows.Foundation.Numerics.Vector2]) -> Void: ...
    FocalLength = property(get_FocalLength, None)
    ImageHeight = property(get_ImageHeight, None)
    ImageWidth = property(get_ImageWidth, None)
    PrincipalPoint = property(get_PrincipalPoint, None)
    RadialDistortion = property(get_RadialDistortion, None)
    TangentialDistortion = property(get_TangentialDistortion, None)
class ICameraIntrinsics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Devices.Core.ICameraIntrinsics2'
    _iid_ = Guid('{0cdaa447-0798-4b4d-839f-c5ec414db27a}')
    @winrt_commethod(6)
    def get_UndistortedProjectionTransform(self) -> win32more.Windows.Foundation.Numerics.Matrix4x4: ...
    @winrt_commethod(7)
    def DistortPoint(self, input: win32more.Windows.Foundation.Point) -> win32more.Windows.Foundation.Point: ...
    @winrt_commethod(8)
    def DistortPoints(self, inputs: PassArray[win32more.Windows.Foundation.Point], results: FillArray[win32more.Windows.Foundation.Point]) -> Void: ...
    @winrt_commethod(9)
    def UndistortPoint(self, input: win32more.Windows.Foundation.Point) -> win32more.Windows.Foundation.Point: ...
    @winrt_commethod(10)
    def UndistortPoints(self, inputs: PassArray[win32more.Windows.Foundation.Point], results: FillArray[win32more.Windows.Foundation.Point]) -> Void: ...
    UndistortedProjectionTransform = property(get_UndistortedProjectionTransform, None)
class ICameraIntrinsicsFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Devices.Core.ICameraIntrinsicsFactory'
    _iid_ = Guid('{c0ddc486-2132-4a34-a659-9bfe2a055712}')
    @winrt_commethod(6)
    def Create(self, focalLength: win32more.Windows.Foundation.Numerics.Vector2, principalPoint: win32more.Windows.Foundation.Numerics.Vector2, radialDistortion: win32more.Windows.Foundation.Numerics.Vector3, tangentialDistortion: win32more.Windows.Foundation.Numerics.Vector2, imageWidth: UInt32, imageHeight: UInt32) -> win32more.Windows.Media.Devices.Core.CameraIntrinsics: ...
class IDepthCorrelatedCoordinateMapper(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[ContextManagerProtocol]
    _classid_ = 'Windows.Media.Devices.Core.IDepthCorrelatedCoordinateMapper'
    _iid_ = Guid('{f95d89fb-8af0-4cb0-926d-696866e5046a}')
    @winrt_commethod(6)
    def UnprojectPoint(self, sourcePoint: win32more.Windows.Foundation.Point, targetCoordinateSystem: win32more.Windows.Perception.Spatial.SpatialCoordinateSystem) -> win32more.Windows.Foundation.Numerics.Vector3: ...
    @winrt_commethod(7)
    def UnprojectPoints(self, sourcePoints: PassArray[win32more.Windows.Foundation.Point], targetCoordinateSystem: win32more.Windows.Perception.Spatial.SpatialCoordinateSystem, results: FillArray[win32more.Windows.Foundation.Numerics.Vector3]) -> Void: ...
    @winrt_commethod(8)
    def MapPoint(self, sourcePoint: win32more.Windows.Foundation.Point, targetCoordinateSystem: win32more.Windows.Perception.Spatial.SpatialCoordinateSystem, targetCameraIntrinsics: win32more.Windows.Media.Devices.Core.CameraIntrinsics) -> win32more.Windows.Foundation.Point: ...
    @winrt_commethod(9)
    def MapPoints(self, sourcePoints: PassArray[win32more.Windows.Foundation.Point], targetCoordinateSystem: win32more.Windows.Perception.Spatial.SpatialCoordinateSystem, targetCameraIntrinsics: win32more.Windows.Media.Devices.Core.CameraIntrinsics, results: FillArray[win32more.Windows.Foundation.Point]) -> Void: ...
class IFrameControlCapabilities(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Devices.Core.IFrameControlCapabilities'
    _iid_ = Guid('{a8ffae60-4e9e-4377-a789-e24c4ae7e544}')
    @winrt_commethod(6)
    def get_Exposure(self) -> win32more.Windows.Media.Devices.Core.FrameExposureCapabilities: ...
    @winrt_commethod(7)
    def get_ExposureCompensation(self) -> win32more.Windows.Media.Devices.Core.FrameExposureCompensationCapabilities: ...
    @winrt_commethod(8)
    def get_IsoSpeed(self) -> win32more.Windows.Media.Devices.Core.FrameIsoSpeedCapabilities: ...
    @winrt_commethod(9)
    def get_Focus(self) -> win32more.Windows.Media.Devices.Core.FrameFocusCapabilities: ...
    @winrt_commethod(10)
    def get_PhotoConfirmationSupported(self) -> Boolean: ...
    Exposure = property(get_Exposure, None)
    ExposureCompensation = property(get_ExposureCompensation, None)
    Focus = property(get_Focus, None)
    IsoSpeed = property(get_IsoSpeed, None)
    PhotoConfirmationSupported = property(get_PhotoConfirmationSupported, None)
class IFrameControlCapabilities2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Devices.Core.IFrameControlCapabilities2'
    _iid_ = Guid('{ce9b0464-4730-440f-bd3e-efe8a8f230a8}')
    @winrt_commethod(6)
    def get_Flash(self) -> win32more.Windows.Media.Devices.Core.FrameFlashCapabilities: ...
    Flash = property(get_Flash, None)
class IFrameController(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Devices.Core.IFrameController'
    _iid_ = Guid('{c16459d9-baef-4052-9177-48aff2af7522}')
    @winrt_commethod(6)
    def get_ExposureControl(self) -> win32more.Windows.Media.Devices.Core.FrameExposureControl: ...
    @winrt_commethod(7)
    def get_ExposureCompensationControl(self) -> win32more.Windows.Media.Devices.Core.FrameExposureCompensationControl: ...
    @winrt_commethod(8)
    def get_IsoSpeedControl(self) -> win32more.Windows.Media.Devices.Core.FrameIsoSpeedControl: ...
    @winrt_commethod(9)
    def get_FocusControl(self) -> win32more.Windows.Media.Devices.Core.FrameFocusControl: ...
    @winrt_commethod(10)
    def get_PhotoConfirmationEnabled(self) -> win32more.Windows.Foundation.IReference[Boolean]: ...
    @winrt_commethod(11)
    def put_PhotoConfirmationEnabled(self, value: win32more.Windows.Foundation.IReference[Boolean]) -> Void: ...
    ExposureCompensationControl = property(get_ExposureCompensationControl, None)
    ExposureControl = property(get_ExposureControl, None)
    FocusControl = property(get_FocusControl, None)
    IsoSpeedControl = property(get_IsoSpeedControl, None)
    PhotoConfirmationEnabled = property(get_PhotoConfirmationEnabled, put_PhotoConfirmationEnabled)
class IFrameController2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Devices.Core.IFrameController2'
    _iid_ = Guid('{00d3bc75-d87c-485b-8a09-5c358568b427}')
    @winrt_commethod(6)
    def get_FlashControl(self) -> win32more.Windows.Media.Devices.Core.FrameFlashControl: ...
    FlashControl = property(get_FlashControl, None)
class IFrameExposureCapabilities(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Devices.Core.IFrameExposureCapabilities'
    _iid_ = Guid('{bdbe9ce3-3985-4e72-97c2-0590d61307a1}')
    @winrt_commethod(6)
    def get_Supported(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_Min(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(8)
    def get_Max(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(9)
    def get_Step(self) -> win32more.Windows.Foundation.TimeSpan: ...
    Max = property(get_Max, None)
    Min = property(get_Min, None)
    Step = property(get_Step, None)
    Supported = property(get_Supported, None)
class IFrameExposureCompensationCapabilities(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Devices.Core.IFrameExposureCompensationCapabilities'
    _iid_ = Guid('{b988a823-8065-41ee-b04f-722265954500}')
    @winrt_commethod(6)
    def get_Supported(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_Min(self) -> Single: ...
    @winrt_commethod(8)
    def get_Max(self) -> Single: ...
    @winrt_commethod(9)
    def get_Step(self) -> Single: ...
    Max = property(get_Max, None)
    Min = property(get_Min, None)
    Step = property(get_Step, None)
    Supported = property(get_Supported, None)
class IFrameExposureCompensationControl(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Devices.Core.IFrameExposureCompensationControl'
    _iid_ = Guid('{e95896c9-f7f9-48ca-8591-a26531cb1578}')
    @winrt_commethod(6)
    def get_Value(self) -> win32more.Windows.Foundation.IReference[Single]: ...
    @winrt_commethod(7)
    def put_Value(self, value: win32more.Windows.Foundation.IReference[Single]) -> Void: ...
    Value = property(get_Value, put_Value)
class IFrameExposureControl(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Devices.Core.IFrameExposureControl'
    _iid_ = Guid('{b1605a61-ffaf-4752-b621-f5b6f117f432}')
    @winrt_commethod(6)
    def get_Auto(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_Auto(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_Value(self) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.TimeSpan]: ...
    @winrt_commethod(9)
    def put_Value(self, value: win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.TimeSpan]) -> Void: ...
    Auto = property(get_Auto, put_Auto)
    Value = property(get_Value, put_Value)
class IFrameFlashCapabilities(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Devices.Core.IFrameFlashCapabilities'
    _iid_ = Guid('{bb9341a2-5ebe-4f62-8223-0e2b05bfbbd0}')
    @winrt_commethod(6)
    def get_Supported(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_RedEyeReductionSupported(self) -> Boolean: ...
    @winrt_commethod(8)
    def get_PowerSupported(self) -> Boolean: ...
    PowerSupported = property(get_PowerSupported, None)
    RedEyeReductionSupported = property(get_RedEyeReductionSupported, None)
    Supported = property(get_Supported, None)
class IFrameFlashControl(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Devices.Core.IFrameFlashControl'
    _iid_ = Guid('{75d5f6c7-bd45-4fab-9375-45ac04b332c2}')
    @winrt_commethod(6)
    def get_Mode(self) -> win32more.Windows.Media.Devices.Core.FrameFlashMode: ...
    @winrt_commethod(7)
    def put_Mode(self, value: win32more.Windows.Media.Devices.Core.FrameFlashMode) -> Void: ...
    @winrt_commethod(8)
    def get_Auto(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_Auto(self, value: Boolean) -> Void: ...
    @winrt_commethod(10)
    def get_RedEyeReduction(self) -> Boolean: ...
    @winrt_commethod(11)
    def put_RedEyeReduction(self, value: Boolean) -> Void: ...
    @winrt_commethod(12)
    def get_PowerPercent(self) -> Single: ...
    @winrt_commethod(13)
    def put_PowerPercent(self, value: Single) -> Void: ...
    Auto = property(get_Auto, put_Auto)
    Mode = property(get_Mode, put_Mode)
    PowerPercent = property(get_PowerPercent, put_PowerPercent)
    RedEyeReduction = property(get_RedEyeReduction, put_RedEyeReduction)
class IFrameFocusCapabilities(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Devices.Core.IFrameFocusCapabilities'
    _iid_ = Guid('{7b25cd58-01c0-4065-9c40-c1a721425c1a}')
    @winrt_commethod(6)
    def get_Supported(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_Min(self) -> UInt32: ...
    @winrt_commethod(8)
    def get_Max(self) -> UInt32: ...
    @winrt_commethod(9)
    def get_Step(self) -> UInt32: ...
    Max = property(get_Max, None)
    Min = property(get_Min, None)
    Step = property(get_Step, None)
    Supported = property(get_Supported, None)
class IFrameFocusControl(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Devices.Core.IFrameFocusControl'
    _iid_ = Guid('{272df1d0-d912-4214-a67b-e38a8d48d8c6}')
    @winrt_commethod(6)
    def get_Value(self) -> win32more.Windows.Foundation.IReference[UInt32]: ...
    @winrt_commethod(7)
    def put_Value(self, value: win32more.Windows.Foundation.IReference[UInt32]) -> Void: ...
    Value = property(get_Value, put_Value)
class IFrameIsoSpeedCapabilities(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Devices.Core.IFrameIsoSpeedCapabilities'
    _iid_ = Guid('{16bdff61-6df6-4ac9-b92a-9f6ecd1ad2fa}')
    @winrt_commethod(6)
    def get_Supported(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_Min(self) -> UInt32: ...
    @winrt_commethod(8)
    def get_Max(self) -> UInt32: ...
    @winrt_commethod(9)
    def get_Step(self) -> UInt32: ...
    Max = property(get_Max, None)
    Min = property(get_Min, None)
    Step = property(get_Step, None)
    Supported = property(get_Supported, None)
class IFrameIsoSpeedControl(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Devices.Core.IFrameIsoSpeedControl'
    _iid_ = Guid('{1a03efed-786a-4c75-a557-7ab9a85f588c}')
    @winrt_commethod(6)
    def get_Auto(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_Auto(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_Value(self) -> win32more.Windows.Foundation.IReference[UInt32]: ...
    @winrt_commethod(9)
    def put_Value(self, value: win32more.Windows.Foundation.IReference[UInt32]) -> Void: ...
    Auto = property(get_Auto, put_Auto)
    Value = property(get_Value, put_Value)
class IVariablePhotoSequenceController(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Devices.Core.IVariablePhotoSequenceController'
    _iid_ = Guid('{7fbff880-ed8c-43fd-a7c3-b35809e4229a}')
    @winrt_commethod(6)
    def get_Supported(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_MaxPhotosPerSecond(self) -> Single: ...
    @winrt_commethod(8)
    def get_PhotosPerSecondLimit(self) -> Single: ...
    @winrt_commethod(9)
    def put_PhotosPerSecondLimit(self, value: Single) -> Void: ...
    @winrt_commethod(10)
    def GetHighestConcurrentFrameRate(self, captureProperties: win32more.Windows.Media.MediaProperties.IMediaEncodingProperties) -> win32more.Windows.Media.MediaProperties.MediaRatio: ...
    @winrt_commethod(11)
    def GetCurrentFrameRate(self) -> win32more.Windows.Media.MediaProperties.MediaRatio: ...
    @winrt_commethod(12)
    def get_FrameCapabilities(self) -> win32more.Windows.Media.Devices.Core.FrameControlCapabilities: ...
    @winrt_commethod(13)
    def get_DesiredFrameControllers(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Media.Devices.Core.FrameController]: ...
    DesiredFrameControllers = property(get_DesiredFrameControllers, None)
    FrameCapabilities = property(get_FrameCapabilities, None)
    MaxPhotosPerSecond = property(get_MaxPhotosPerSecond, None)
    PhotosPerSecondLimit = property(get_PhotosPerSecondLimit, put_PhotosPerSecondLimit)
    Supported = property(get_Supported, None)
class VariablePhotoSequenceController(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.Devices.Core.IVariablePhotoSequenceController
    _classid_ = 'Windows.Media.Devices.Core.VariablePhotoSequenceController'
    @winrt_mixinmethod
    def get_Supported(self: win32more.Windows.Media.Devices.Core.IVariablePhotoSequenceController) -> Boolean: ...
    @winrt_mixinmethod
    def get_MaxPhotosPerSecond(self: win32more.Windows.Media.Devices.Core.IVariablePhotoSequenceController) -> Single: ...
    @winrt_mixinmethod
    def get_PhotosPerSecondLimit(self: win32more.Windows.Media.Devices.Core.IVariablePhotoSequenceController) -> Single: ...
    @winrt_mixinmethod
    def put_PhotosPerSecondLimit(self: win32more.Windows.Media.Devices.Core.IVariablePhotoSequenceController, value: Single) -> Void: ...
    @winrt_mixinmethod
    def GetHighestConcurrentFrameRate(self: win32more.Windows.Media.Devices.Core.IVariablePhotoSequenceController, captureProperties: win32more.Windows.Media.MediaProperties.IMediaEncodingProperties) -> win32more.Windows.Media.MediaProperties.MediaRatio: ...
    @winrt_mixinmethod
    def GetCurrentFrameRate(self: win32more.Windows.Media.Devices.Core.IVariablePhotoSequenceController) -> win32more.Windows.Media.MediaProperties.MediaRatio: ...
    @winrt_mixinmethod
    def get_FrameCapabilities(self: win32more.Windows.Media.Devices.Core.IVariablePhotoSequenceController) -> win32more.Windows.Media.Devices.Core.FrameControlCapabilities: ...
    @winrt_mixinmethod
    def get_DesiredFrameControllers(self: win32more.Windows.Media.Devices.Core.IVariablePhotoSequenceController) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Media.Devices.Core.FrameController]: ...
    DesiredFrameControllers = property(get_DesiredFrameControllers, None)
    FrameCapabilities = property(get_FrameCapabilities, None)
    MaxPhotosPerSecond = property(get_MaxPhotosPerSecond, None)
    PhotosPerSecondLimit = property(get_PhotosPerSecondLimit, put_PhotosPerSecondLimit)
    Supported = property(get_Supported, None)


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Foundation
import win32more.Windows.Globalization.PhoneNumberFormatting
import win32more.Windows.Win32.System.WinRT
class IPhoneNumberFormatter(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Globalization.PhoneNumberFormatting.IPhoneNumberFormatter'
    _iid_ = Guid('{1556b49e-bad4-4b4a-900d-4407adb7c981}')
    @winrt_commethod(6)
    def Format(self, number: win32more.Windows.Globalization.PhoneNumberFormatting.PhoneNumberInfo) -> WinRT_String: ...
    @winrt_commethod(7)
    def FormatWithOutputFormat(self, number: win32more.Windows.Globalization.PhoneNumberFormatting.PhoneNumberInfo, numberFormat: win32more.Windows.Globalization.PhoneNumberFormatting.PhoneNumberFormat) -> WinRT_String: ...
    @winrt_commethod(8)
    def FormatPartialString(self, number: WinRT_String) -> WinRT_String: ...
    @winrt_commethod(9)
    def FormatString(self, number: WinRT_String) -> WinRT_String: ...
    @winrt_commethod(10)
    def FormatStringWithLeftToRightMarkers(self, number: WinRT_String) -> WinRT_String: ...
class IPhoneNumberFormatterStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Globalization.PhoneNumberFormatting.IPhoneNumberFormatterStatics'
    _iid_ = Guid('{5ca6f931-84d9-414b-ab4e-a0552c878602}')
    @winrt_commethod(6)
    def TryCreate(self, regionCode: WinRT_String, phoneNumber: POINTER(win32more.Windows.Globalization.PhoneNumberFormatting.PhoneNumberFormatter)) -> Void: ...
    @winrt_commethod(7)
    def GetCountryCodeForRegion(self, regionCode: WinRT_String) -> Int32: ...
    @winrt_commethod(8)
    def GetNationalDirectDialingPrefixForRegion(self, regionCode: WinRT_String, stripNonDigit: Boolean) -> WinRT_String: ...
    @winrt_commethod(9)
    def WrapWithLeftToRightMarkers(self, number: WinRT_String) -> WinRT_String: ...
class IPhoneNumberInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Globalization.PhoneNumberFormatting.IPhoneNumberInfo'
    _iid_ = Guid('{1c7ce4dd-c8b4-4ea3-9aef-b342e2c5b417}')
    @winrt_commethod(6)
    def get_CountryCode(self) -> Int32: ...
    @winrt_commethod(7)
    def get_PhoneNumber(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def GetLengthOfGeographicalAreaCode(self) -> Int32: ...
    @winrt_commethod(9)
    def GetNationalSignificantNumber(self) -> WinRT_String: ...
    @winrt_commethod(10)
    def GetLengthOfNationalDestinationCode(self) -> Int32: ...
    @winrt_commethod(11)
    def PredictNumberKind(self) -> win32more.Windows.Globalization.PhoneNumberFormatting.PredictedPhoneNumberKind: ...
    @winrt_commethod(12)
    def GetGeographicRegionCode(self) -> WinRT_String: ...
    @winrt_commethod(13)
    def CheckNumberMatch(self, otherNumber: win32more.Windows.Globalization.PhoneNumberFormatting.PhoneNumberInfo) -> win32more.Windows.Globalization.PhoneNumberFormatting.PhoneNumberMatchResult: ...
    CountryCode = property(get_CountryCode, None)
    PhoneNumber = property(get_PhoneNumber, None)
class IPhoneNumberInfoFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Globalization.PhoneNumberFormatting.IPhoneNumberInfoFactory'
    _iid_ = Guid('{8202b964-adaa-4cff-8fcf-17e7516a28ff}')
    @winrt_commethod(6)
    def Create(self, number: WinRT_String) -> win32more.Windows.Globalization.PhoneNumberFormatting.PhoneNumberInfo: ...
class IPhoneNumberInfoStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Globalization.PhoneNumberFormatting.IPhoneNumberInfoStatics'
    _iid_ = Guid('{5b3f4f6a-86a9-40e9-8649-6d61161928d4}')
    @winrt_commethod(6)
    def TryParse(self, input: WinRT_String, phoneNumber: POINTER(win32more.Windows.Globalization.PhoneNumberFormatting.PhoneNumberInfo)) -> win32more.Windows.Globalization.PhoneNumberFormatting.PhoneNumberParseResult: ...
    @winrt_commethod(7)
    def TryParseWithRegion(self, input: WinRT_String, regionCode: WinRT_String, phoneNumber: POINTER(win32more.Windows.Globalization.PhoneNumberFormatting.PhoneNumberInfo)) -> win32more.Windows.Globalization.PhoneNumberFormatting.PhoneNumberParseResult: ...
class PhoneNumberFormat(Enum, Int32):
    E164 = 0
    International = 1
    National = 2
    Rfc3966 = 3
class PhoneNumberFormatter(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Globalization.PhoneNumberFormatting.IPhoneNumberFormatter
    _classid_ = 'Windows.Globalization.PhoneNumberFormatting.PhoneNumberFormatter'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.Globalization.PhoneNumberFormatting.PhoneNumberFormatter.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.Globalization.PhoneNumberFormatting.PhoneNumberFormatter: ...
    @winrt_mixinmethod
    def Format(self: win32more.Windows.Globalization.PhoneNumberFormatting.IPhoneNumberFormatter, number: win32more.Windows.Globalization.PhoneNumberFormatting.PhoneNumberInfo) -> WinRT_String: ...
    @winrt_mixinmethod
    def FormatWithOutputFormat(self: win32more.Windows.Globalization.PhoneNumberFormatting.IPhoneNumberFormatter, number: win32more.Windows.Globalization.PhoneNumberFormatting.PhoneNumberInfo, numberFormat: win32more.Windows.Globalization.PhoneNumberFormatting.PhoneNumberFormat) -> WinRT_String: ...
    @winrt_mixinmethod
    def FormatPartialString(self: win32more.Windows.Globalization.PhoneNumberFormatting.IPhoneNumberFormatter, number: WinRT_String) -> WinRT_String: ...
    @winrt_mixinmethod
    def FormatString(self: win32more.Windows.Globalization.PhoneNumberFormatting.IPhoneNumberFormatter, number: WinRT_String) -> WinRT_String: ...
    @winrt_mixinmethod
    def FormatStringWithLeftToRightMarkers(self: win32more.Windows.Globalization.PhoneNumberFormatting.IPhoneNumberFormatter, number: WinRT_String) -> WinRT_String: ...
    @winrt_classmethod
    def TryCreate(cls: win32more.Windows.Globalization.PhoneNumberFormatting.IPhoneNumberFormatterStatics, regionCode: WinRT_String, phoneNumber: POINTER(win32more.Windows.Globalization.PhoneNumberFormatting.PhoneNumberFormatter)) -> Void: ...
    @winrt_classmethod
    def GetCountryCodeForRegion(cls: win32more.Windows.Globalization.PhoneNumberFormatting.IPhoneNumberFormatterStatics, regionCode: WinRT_String) -> Int32: ...
    @winrt_classmethod
    def GetNationalDirectDialingPrefixForRegion(cls: win32more.Windows.Globalization.PhoneNumberFormatting.IPhoneNumberFormatterStatics, regionCode: WinRT_String, stripNonDigit: Boolean) -> WinRT_String: ...
    @winrt_classmethod
    def WrapWithLeftToRightMarkers(cls: win32more.Windows.Globalization.PhoneNumberFormatting.IPhoneNumberFormatterStatics, number: WinRT_String) -> WinRT_String: ...
class PhoneNumberInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Globalization.PhoneNumberFormatting.IPhoneNumberInfo
    _classid_ = 'Windows.Globalization.PhoneNumberFormatting.PhoneNumberInfo'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 1:
            super().__init__(move=win32more.Windows.Globalization.PhoneNumberFormatting.PhoneNumberInfo.Create(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def Create(cls: win32more.Windows.Globalization.PhoneNumberFormatting.IPhoneNumberInfoFactory, number: WinRT_String) -> win32more.Windows.Globalization.PhoneNumberFormatting.PhoneNumberInfo: ...
    @winrt_mixinmethod
    def get_CountryCode(self: win32more.Windows.Globalization.PhoneNumberFormatting.IPhoneNumberInfo) -> Int32: ...
    @winrt_mixinmethod
    def get_PhoneNumber(self: win32more.Windows.Globalization.PhoneNumberFormatting.IPhoneNumberInfo) -> WinRT_String: ...
    @winrt_mixinmethod
    def GetLengthOfGeographicalAreaCode(self: win32more.Windows.Globalization.PhoneNumberFormatting.IPhoneNumberInfo) -> Int32: ...
    @winrt_mixinmethod
    def GetNationalSignificantNumber(self: win32more.Windows.Globalization.PhoneNumberFormatting.IPhoneNumberInfo) -> WinRT_String: ...
    @winrt_mixinmethod
    def GetLengthOfNationalDestinationCode(self: win32more.Windows.Globalization.PhoneNumberFormatting.IPhoneNumberInfo) -> Int32: ...
    @winrt_mixinmethod
    def PredictNumberKind(self: win32more.Windows.Globalization.PhoneNumberFormatting.IPhoneNumberInfo) -> win32more.Windows.Globalization.PhoneNumberFormatting.PredictedPhoneNumberKind: ...
    @winrt_mixinmethod
    def GetGeographicRegionCode(self: win32more.Windows.Globalization.PhoneNumberFormatting.IPhoneNumberInfo) -> WinRT_String: ...
    @winrt_mixinmethod
    def CheckNumberMatch(self: win32more.Windows.Globalization.PhoneNumberFormatting.IPhoneNumberInfo, otherNumber: win32more.Windows.Globalization.PhoneNumberFormatting.PhoneNumberInfo) -> win32more.Windows.Globalization.PhoneNumberFormatting.PhoneNumberMatchResult: ...
    @winrt_mixinmethod
    def ToString(self: win32more.Windows.Foundation.IStringable) -> WinRT_String: ...
    @winrt_classmethod
    def TryParse(cls: win32more.Windows.Globalization.PhoneNumberFormatting.IPhoneNumberInfoStatics, input: WinRT_String, phoneNumber: POINTER(win32more.Windows.Globalization.PhoneNumberFormatting.PhoneNumberInfo)) -> win32more.Windows.Globalization.PhoneNumberFormatting.PhoneNumberParseResult: ...
    @winrt_classmethod
    def TryParseWithRegion(cls: win32more.Windows.Globalization.PhoneNumberFormatting.IPhoneNumberInfoStatics, input: WinRT_String, regionCode: WinRT_String, phoneNumber: POINTER(win32more.Windows.Globalization.PhoneNumberFormatting.PhoneNumberInfo)) -> win32more.Windows.Globalization.PhoneNumberFormatting.PhoneNumberParseResult: ...
    CountryCode = property(get_CountryCode, None)
    PhoneNumber = property(get_PhoneNumber, None)
class PhoneNumberMatchResult(Enum, Int32):
    NoMatch = 0
    ShortNationalSignificantNumberMatch = 1
    NationalSignificantNumberMatch = 2
    ExactMatch = 3
class PhoneNumberParseResult(Enum, Int32):
    Valid = 0
    NotANumber = 1
    InvalidCountryCode = 2
    TooShort = 3
    TooLong = 4
class PredictedPhoneNumberKind(Enum, Int32):
    FixedLine = 0
    Mobile = 1
    FixedLineOrMobile = 2
    TollFree = 3
    PremiumRate = 4
    SharedCost = 5
    Voip = 6
    PersonalNumber = 7
    Pager = 8
    UniversalAccountNumber = 9
    Voicemail = 10
    Unknown = 11


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.AI.MachineLearning.WinML
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Graphics.Direct3D12
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.System.WinRT.ML
class ILearningModelDeviceFactoryNative(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{1e9b31a1-662e-4ae0-af67-f63bb337e634}')
    @commethod(3)
    def CreateFromD3D12CommandQueue(self, value: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12CommandQueue, result: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ILearningModelOperatorProviderNative(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{1adaa23a-eb67-41f3-aad8-5d984e9bacd4}')
    @commethod(3)
    def GetRegistry(self, ppOperatorRegistry: POINTER(win32more.Windows.Win32.AI.MachineLearning.WinML.IMLOperatorRegistry)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ILearningModelSessionOptionsNative(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{c71e953f-37b4-4564-8658-d8396866db0d}')
    @commethod(3)
    def SetIntraOpNumThreadsOverride(self, intraOpNumThreads: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ILearningModelSessionOptionsNative1(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{5da37a26-0526-414b-91e4-2a0fa3ddba40}')
    @commethod(3)
    def SetIntraOpThreadSpinning(self, allowSpinning: Byte) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ITensorNative(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{52f547ef-5b03-49b5-82d6-565f1ee0dd49}')
    @commethod(3)
    def GetBuffer(self, value: POINTER(POINTER(Byte)), capacity: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetD3D12Resource(self, result: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ITensorStaticsNative(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{39d055a4-66f6-4ebc-95d9-7a29ebe7690a}')
    @commethod(3)
    def CreateFromD3D12Resource(self, value: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource, shape: POINTER(Int64), shapeCount: Int32, result: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Graphics.Dwm
import win32more.Windows.Win32.Graphics.Gdi
import win32more.Windows.Win32.UI.Controls
DWM_BB_ENABLE: UInt32 = 1
DWM_BB_BLURREGION: UInt32 = 2
DWM_BB_TRANSITIONONMAXIMIZED: UInt32 = 4
DWMWA_COLOR_DEFAULT: UInt32 = 4294967295
DWMWA_COLOR_NONE: UInt32 = 4294967294
DWM_CLOAKED_APP: UInt32 = 1
DWM_CLOAKED_SHELL: UInt32 = 2
DWM_CLOAKED_INHERITED: UInt32 = 4
DWM_TNP_RECTDESTINATION: UInt32 = 1
DWM_TNP_RECTSOURCE: UInt32 = 2
DWM_TNP_OPACITY: UInt32 = 4
DWM_TNP_VISIBLE: UInt32 = 8
DWM_TNP_SOURCECLIENTAREAONLY: UInt32 = 16
DWM_FRAME_DURATION_DEFAULT: Int32 = -1
DWM_EC_DISABLECOMPOSITION: UInt32 = 0
DWM_EC_ENABLECOMPOSITION: UInt32 = 1
DWM_SIT_DISPLAYFRAME: UInt32 = 1
c_DwmMaxQueuedBuffers: UInt32 = 8
c_DwmMaxMonitors: UInt32 = 16
c_DwmMaxAdapters: UInt32 = 16
@winfunctype('dwmapi.dll')
def DwmDefWindowProc(hWnd: win32more.Windows.Win32.Foundation.HWND, msg: UInt32, wParam: win32more.Windows.Win32.Foundation.WPARAM, lParam: win32more.Windows.Win32.Foundation.LPARAM, plResult: POINTER(win32more.Windows.Win32.Foundation.LRESULT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('dwmapi.dll')
def DwmEnableBlurBehindWindow(hWnd: win32more.Windows.Win32.Foundation.HWND, pBlurBehind: POINTER(win32more.Windows.Win32.Graphics.Dwm.DWM_BLURBEHIND)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('dwmapi.dll')
def DwmEnableComposition(uCompositionAction: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('dwmapi.dll')
def DwmEnableMMCSS(fEnableMMCSS: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('dwmapi.dll')
def DwmExtendFrameIntoClientArea(hWnd: win32more.Windows.Win32.Foundation.HWND, pMarInset: POINTER(win32more.Windows.Win32.UI.Controls.MARGINS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('dwmapi.dll')
def DwmGetColorizationColor(pcrColorization: POINTER(UInt32), pfOpaqueBlend: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('dwmapi.dll')
def DwmGetCompositionTimingInfo(hwnd: win32more.Windows.Win32.Foundation.HWND, pTimingInfo: POINTER(win32more.Windows.Win32.Graphics.Dwm.DWM_TIMING_INFO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('dwmapi.dll')
def DwmGetWindowAttribute(hwnd: win32more.Windows.Win32.Foundation.HWND, dwAttribute: UInt32, pvAttribute: VoidPtr, cbAttribute: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('dwmapi.dll')
def DwmIsCompositionEnabled(pfEnabled: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('dwmapi.dll')
def DwmModifyPreviousDxFrameDuration(hwnd: win32more.Windows.Win32.Foundation.HWND, cRefreshes: Int32, fRelative: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('dwmapi.dll')
def DwmQueryThumbnailSourceSize(hThumbnail: IntPtr, pSize: POINTER(win32more.Windows.Win32.Foundation.SIZE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('dwmapi.dll')
def DwmRegisterThumbnail(hwndDestination: win32more.Windows.Win32.Foundation.HWND, hwndSource: win32more.Windows.Win32.Foundation.HWND, phThumbnailId: POINTER(IntPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('dwmapi.dll')
def DwmSetDxFrameDuration(hwnd: win32more.Windows.Win32.Foundation.HWND, cRefreshes: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('dwmapi.dll')
def DwmSetPresentParameters(hwnd: win32more.Windows.Win32.Foundation.HWND, pPresentParams: POINTER(win32more.Windows.Win32.Graphics.Dwm.DWM_PRESENT_PARAMETERS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('dwmapi.dll')
def DwmSetWindowAttribute(hwnd: win32more.Windows.Win32.Foundation.HWND, dwAttribute: UInt32, pvAttribute: VoidPtr, cbAttribute: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('dwmapi.dll')
def DwmUnregisterThumbnail(hThumbnailId: IntPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('dwmapi.dll')
def DwmUpdateThumbnailProperties(hThumbnailId: IntPtr, ptnProperties: POINTER(win32more.Windows.Win32.Graphics.Dwm.DWM_THUMBNAIL_PROPERTIES)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('dwmapi.dll')
def DwmSetIconicThumbnail(hwnd: win32more.Windows.Win32.Foundation.HWND, hbmp: win32more.Windows.Win32.Graphics.Gdi.HBITMAP, dwSITFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('dwmapi.dll')
def DwmSetIconicLivePreviewBitmap(hwnd: win32more.Windows.Win32.Foundation.HWND, hbmp: win32more.Windows.Win32.Graphics.Gdi.HBITMAP, pptClient: POINTER(win32more.Windows.Win32.Foundation.POINT), dwSITFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('dwmapi.dll')
def DwmInvalidateIconicBitmaps(hwnd: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('dwmapi.dll')
def DwmAttachMilContent(hwnd: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('dwmapi.dll')
def DwmDetachMilContent(hwnd: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('dwmapi.dll')
def DwmFlush() -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('dwmapi.dll')
def DwmGetGraphicsStreamTransformHint(uIndex: UInt32, pTransform: POINTER(win32more.Windows.Win32.Graphics.Dwm.MilMatrix3x2D)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('dwmapi.dll')
def DwmGetGraphicsStreamClient(uIndex: UInt32, pClientUuid: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('dwmapi.dll')
def DwmGetTransportAttributes(pfIsRemoting: POINTER(win32more.Windows.Win32.Foundation.BOOL), pfIsConnected: POINTER(win32more.Windows.Win32.Foundation.BOOL), pDwGeneration: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('dwmapi.dll')
def DwmTransitionOwnedWindow(hwnd: win32more.Windows.Win32.Foundation.HWND, target: win32more.Windows.Win32.Graphics.Dwm.DWMTRANSITION_OWNEDWINDOW_TARGET) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('dwmapi.dll')
def DwmRenderGesture(gt: win32more.Windows.Win32.Graphics.Dwm.GESTURE_TYPE, cContacts: UInt32, pdwPointerID: POINTER(UInt32), pPoints: POINTER(win32more.Windows.Win32.Foundation.POINT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('dwmapi.dll')
def DwmTetherContact(dwPointerID: UInt32, fEnable: win32more.Windows.Win32.Foundation.BOOL, ptTether: win32more.Windows.Win32.Foundation.POINT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('dwmapi.dll')
def DwmShowContact(dwPointerID: UInt32, eShowContact: win32more.Windows.Win32.Graphics.Dwm.DWM_SHOWCONTACT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('dwmapi.dll')
def DwmGetUnmetTabRequirements(appWindow: win32more.Windows.Win32.Foundation.HWND, value: POINTER(win32more.Windows.Win32.Graphics.Dwm.DWM_TAB_WINDOW_REQUIREMENTS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
DWMFLIP3DWINDOWPOLICY = Int32
DWMFLIP3D_DEFAULT: win32more.Windows.Win32.Graphics.Dwm.DWMFLIP3DWINDOWPOLICY = 0
DWMFLIP3D_EXCLUDEBELOW: win32more.Windows.Win32.Graphics.Dwm.DWMFLIP3DWINDOWPOLICY = 1
DWMFLIP3D_EXCLUDEABOVE: win32more.Windows.Win32.Graphics.Dwm.DWMFLIP3DWINDOWPOLICY = 2
DWMFLIP3D_LAST: win32more.Windows.Win32.Graphics.Dwm.DWMFLIP3DWINDOWPOLICY = 3
DWMNCRENDERINGPOLICY = Int32
DWMNCRP_USEWINDOWSTYLE: win32more.Windows.Win32.Graphics.Dwm.DWMNCRENDERINGPOLICY = 0
DWMNCRP_DISABLED: win32more.Windows.Win32.Graphics.Dwm.DWMNCRENDERINGPOLICY = 1
DWMNCRP_ENABLED: win32more.Windows.Win32.Graphics.Dwm.DWMNCRENDERINGPOLICY = 2
DWMNCRP_LAST: win32more.Windows.Win32.Graphics.Dwm.DWMNCRENDERINGPOLICY = 3
DWMTRANSITION_OWNEDWINDOW_TARGET = Int32
DWMTRANSITION_OWNEDWINDOW_NULL: win32more.Windows.Win32.Graphics.Dwm.DWMTRANSITION_OWNEDWINDOW_TARGET = -1
DWMTRANSITION_OWNEDWINDOW_REPOSITION: win32more.Windows.Win32.Graphics.Dwm.DWMTRANSITION_OWNEDWINDOW_TARGET = 0
DWMWINDOWATTRIBUTE = Int32
DWMWA_NCRENDERING_ENABLED: win32more.Windows.Win32.Graphics.Dwm.DWMWINDOWATTRIBUTE = 1
DWMWA_NCRENDERING_POLICY: win32more.Windows.Win32.Graphics.Dwm.DWMWINDOWATTRIBUTE = 2
DWMWA_TRANSITIONS_FORCEDISABLED: win32more.Windows.Win32.Graphics.Dwm.DWMWINDOWATTRIBUTE = 3
DWMWA_ALLOW_NCPAINT: win32more.Windows.Win32.Graphics.Dwm.DWMWINDOWATTRIBUTE = 4
DWMWA_CAPTION_BUTTON_BOUNDS: win32more.Windows.Win32.Graphics.Dwm.DWMWINDOWATTRIBUTE = 5
DWMWA_NONCLIENT_RTL_LAYOUT: win32more.Windows.Win32.Graphics.Dwm.DWMWINDOWATTRIBUTE = 6
DWMWA_FORCE_ICONIC_REPRESENTATION: win32more.Windows.Win32.Graphics.Dwm.DWMWINDOWATTRIBUTE = 7
DWMWA_FLIP3D_POLICY: win32more.Windows.Win32.Graphics.Dwm.DWMWINDOWATTRIBUTE = 8
DWMWA_EXTENDED_FRAME_BOUNDS: win32more.Windows.Win32.Graphics.Dwm.DWMWINDOWATTRIBUTE = 9
DWMWA_HAS_ICONIC_BITMAP: win32more.Windows.Win32.Graphics.Dwm.DWMWINDOWATTRIBUTE = 10
DWMWA_DISALLOW_PEEK: win32more.Windows.Win32.Graphics.Dwm.DWMWINDOWATTRIBUTE = 11
DWMWA_EXCLUDED_FROM_PEEK: win32more.Windows.Win32.Graphics.Dwm.DWMWINDOWATTRIBUTE = 12
DWMWA_CLOAK: win32more.Windows.Win32.Graphics.Dwm.DWMWINDOWATTRIBUTE = 13
DWMWA_CLOAKED: win32more.Windows.Win32.Graphics.Dwm.DWMWINDOWATTRIBUTE = 14
DWMWA_FREEZE_REPRESENTATION: win32more.Windows.Win32.Graphics.Dwm.DWMWINDOWATTRIBUTE = 15
DWMWA_PASSIVE_UPDATE_MODE: win32more.Windows.Win32.Graphics.Dwm.DWMWINDOWATTRIBUTE = 16
DWMWA_USE_HOSTBACKDROPBRUSH: win32more.Windows.Win32.Graphics.Dwm.DWMWINDOWATTRIBUTE = 17
DWMWA_USE_IMMERSIVE_DARK_MODE: win32more.Windows.Win32.Graphics.Dwm.DWMWINDOWATTRIBUTE = 20
DWMWA_WINDOW_CORNER_PREFERENCE: win32more.Windows.Win32.Graphics.Dwm.DWMWINDOWATTRIBUTE = 33
DWMWA_BORDER_COLOR: win32more.Windows.Win32.Graphics.Dwm.DWMWINDOWATTRIBUTE = 34
DWMWA_CAPTION_COLOR: win32more.Windows.Win32.Graphics.Dwm.DWMWINDOWATTRIBUTE = 35
DWMWA_TEXT_COLOR: win32more.Windows.Win32.Graphics.Dwm.DWMWINDOWATTRIBUTE = 36
DWMWA_VISIBLE_FRAME_BORDER_THICKNESS: win32more.Windows.Win32.Graphics.Dwm.DWMWINDOWATTRIBUTE = 37
DWMWA_SYSTEMBACKDROP_TYPE: win32more.Windows.Win32.Graphics.Dwm.DWMWINDOWATTRIBUTE = 38
DWMWA_LAST: win32more.Windows.Win32.Graphics.Dwm.DWMWINDOWATTRIBUTE = 39
class DWM_BLURBEHIND(Structure):
    dwFlags: UInt32
    fEnable: win32more.Windows.Win32.Foundation.BOOL
    hRgnBlur: win32more.Windows.Win32.Graphics.Gdi.HRGN
    fTransitionOnMaximized: win32more.Windows.Win32.Foundation.BOOL
    _pack_ = 1
class DWM_PRESENT_PARAMETERS(Structure):
    cbSize: UInt32
    fQueue: win32more.Windows.Win32.Foundation.BOOL
    cRefreshStart: UInt64
    cBuffer: UInt32
    fUseSourceRate: win32more.Windows.Win32.Foundation.BOOL
    rateSource: win32more.Windows.Win32.Graphics.Dwm.UNSIGNED_RATIO
    cRefreshesPerFrame: UInt32
    eSampling: win32more.Windows.Win32.Graphics.Dwm.DWM_SOURCE_FRAME_SAMPLING
    _pack_ = 1
DWM_SHOWCONTACT = UInt32
DWMSC_DOWN: win32more.Windows.Win32.Graphics.Dwm.DWM_SHOWCONTACT = 1
DWMSC_UP: win32more.Windows.Win32.Graphics.Dwm.DWM_SHOWCONTACT = 2
DWMSC_DRAG: win32more.Windows.Win32.Graphics.Dwm.DWM_SHOWCONTACT = 4
DWMSC_HOLD: win32more.Windows.Win32.Graphics.Dwm.DWM_SHOWCONTACT = 8
DWMSC_PENBARREL: win32more.Windows.Win32.Graphics.Dwm.DWM_SHOWCONTACT = 16
DWMSC_NONE: win32more.Windows.Win32.Graphics.Dwm.DWM_SHOWCONTACT = 0
DWMSC_ALL: win32more.Windows.Win32.Graphics.Dwm.DWM_SHOWCONTACT = 4294967295
DWM_SOURCE_FRAME_SAMPLING = Int32
DWM_SOURCE_FRAME_SAMPLING_POINT: win32more.Windows.Win32.Graphics.Dwm.DWM_SOURCE_FRAME_SAMPLING = 0
DWM_SOURCE_FRAME_SAMPLING_COVERAGE: win32more.Windows.Win32.Graphics.Dwm.DWM_SOURCE_FRAME_SAMPLING = 1
DWM_SOURCE_FRAME_SAMPLING_LAST: win32more.Windows.Win32.Graphics.Dwm.DWM_SOURCE_FRAME_SAMPLING = 2
DWM_SYSTEMBACKDROP_TYPE = Int32
DWMSBT_AUTO: win32more.Windows.Win32.Graphics.Dwm.DWM_SYSTEMBACKDROP_TYPE = 0
DWMSBT_NONE: win32more.Windows.Win32.Graphics.Dwm.DWM_SYSTEMBACKDROP_TYPE = 1
DWMSBT_MAINWINDOW: win32more.Windows.Win32.Graphics.Dwm.DWM_SYSTEMBACKDROP_TYPE = 2
DWMSBT_TRANSIENTWINDOW: win32more.Windows.Win32.Graphics.Dwm.DWM_SYSTEMBACKDROP_TYPE = 3
DWMSBT_TABBEDWINDOW: win32more.Windows.Win32.Graphics.Dwm.DWM_SYSTEMBACKDROP_TYPE = 4
DWM_TAB_WINDOW_REQUIREMENTS = Int32
DWMTWR_NONE: win32more.Windows.Win32.Graphics.Dwm.DWM_TAB_WINDOW_REQUIREMENTS = 0
DWMTWR_IMPLEMENTED_BY_SYSTEM: win32more.Windows.Win32.Graphics.Dwm.DWM_TAB_WINDOW_REQUIREMENTS = 1
DWMTWR_WINDOW_RELATIONSHIP: win32more.Windows.Win32.Graphics.Dwm.DWM_TAB_WINDOW_REQUIREMENTS = 2
DWMTWR_WINDOW_STYLES: win32more.Windows.Win32.Graphics.Dwm.DWM_TAB_WINDOW_REQUIREMENTS = 4
DWMTWR_WINDOW_REGION: win32more.Windows.Win32.Graphics.Dwm.DWM_TAB_WINDOW_REQUIREMENTS = 8
DWMTWR_WINDOW_DWM_ATTRIBUTES: win32more.Windows.Win32.Graphics.Dwm.DWM_TAB_WINDOW_REQUIREMENTS = 16
DWMTWR_WINDOW_MARGINS: win32more.Windows.Win32.Graphics.Dwm.DWM_TAB_WINDOW_REQUIREMENTS = 32
DWMTWR_TABBING_ENABLED: win32more.Windows.Win32.Graphics.Dwm.DWM_TAB_WINDOW_REQUIREMENTS = 64
DWMTWR_USER_POLICY: win32more.Windows.Win32.Graphics.Dwm.DWM_TAB_WINDOW_REQUIREMENTS = 128
DWMTWR_GROUP_POLICY: win32more.Windows.Win32.Graphics.Dwm.DWM_TAB_WINDOW_REQUIREMENTS = 256
DWMTWR_APP_COMPAT: win32more.Windows.Win32.Graphics.Dwm.DWM_TAB_WINDOW_REQUIREMENTS = 512
class DWM_THUMBNAIL_PROPERTIES(Structure):
    dwFlags: UInt32
    rcDestination: win32more.Windows.Win32.Foundation.RECT
    rcSource: win32more.Windows.Win32.Foundation.RECT
    opacity: Byte
    fVisible: win32more.Windows.Win32.Foundation.BOOL
    fSourceClientAreaOnly: win32more.Windows.Win32.Foundation.BOOL
    _pack_ = 1
class DWM_TIMING_INFO(Structure):
    cbSize: UInt32
    rateRefresh: win32more.Windows.Win32.Graphics.Dwm.UNSIGNED_RATIO
    qpcRefreshPeriod: UInt64
    rateCompose: win32more.Windows.Win32.Graphics.Dwm.UNSIGNED_RATIO
    qpcVBlank: UInt64
    cRefresh: UInt64
    cDXRefresh: UInt32
    qpcCompose: UInt64
    cFrame: UInt64
    cDXPresent: UInt32
    cRefreshFrame: UInt64
    cFrameSubmitted: UInt64
    cDXPresentSubmitted: UInt32
    cFrameConfirmed: UInt64
    cDXPresentConfirmed: UInt32
    cRefreshConfirmed: UInt64
    cDXRefreshConfirmed: UInt32
    cFramesLate: UInt64
    cFramesOutstanding: UInt32
    cFrameDisplayed: UInt64
    qpcFrameDisplayed: UInt64
    cRefreshFrameDisplayed: UInt64
    cFrameComplete: UInt64
    qpcFrameComplete: UInt64
    cFramePending: UInt64
    qpcFramePending: UInt64
    cFramesDisplayed: UInt64
    cFramesComplete: UInt64
    cFramesPending: UInt64
    cFramesAvailable: UInt64
    cFramesDropped: UInt64
    cFramesMissed: UInt64
    cRefreshNextDisplayed: UInt64
    cRefreshNextPresented: UInt64
    cRefreshesDisplayed: UInt64
    cRefreshesPresented: UInt64
    cRefreshStarted: UInt64
    cPixelsReceived: UInt64
    cPixelsDrawn: UInt64
    cBuffersEmpty: UInt64
    _pack_ = 1
DWM_WINDOW_CORNER_PREFERENCE = Int32
DWMWCP_DEFAULT: win32more.Windows.Win32.Graphics.Dwm.DWM_WINDOW_CORNER_PREFERENCE = 0
DWMWCP_DONOTROUND: win32more.Windows.Win32.Graphics.Dwm.DWM_WINDOW_CORNER_PREFERENCE = 1
DWMWCP_ROUND: win32more.Windows.Win32.Graphics.Dwm.DWM_WINDOW_CORNER_PREFERENCE = 2
DWMWCP_ROUNDSMALL: win32more.Windows.Win32.Graphics.Dwm.DWM_WINDOW_CORNER_PREFERENCE = 3
GESTURE_TYPE = Int32
GT_PEN_TAP: win32more.Windows.Win32.Graphics.Dwm.GESTURE_TYPE = 0
GT_PEN_DOUBLETAP: win32more.Windows.Win32.Graphics.Dwm.GESTURE_TYPE = 1
GT_PEN_RIGHTTAP: win32more.Windows.Win32.Graphics.Dwm.GESTURE_TYPE = 2
GT_PEN_PRESSANDHOLD: win32more.Windows.Win32.Graphics.Dwm.GESTURE_TYPE = 3
GT_PEN_PRESSANDHOLDABORT: win32more.Windows.Win32.Graphics.Dwm.GESTURE_TYPE = 4
GT_TOUCH_TAP: win32more.Windows.Win32.Graphics.Dwm.GESTURE_TYPE = 5
GT_TOUCH_DOUBLETAP: win32more.Windows.Win32.Graphics.Dwm.GESTURE_TYPE = 6
GT_TOUCH_RIGHTTAP: win32more.Windows.Win32.Graphics.Dwm.GESTURE_TYPE = 7
GT_TOUCH_PRESSANDHOLD: win32more.Windows.Win32.Graphics.Dwm.GESTURE_TYPE = 8
GT_TOUCH_PRESSANDHOLDABORT: win32more.Windows.Win32.Graphics.Dwm.GESTURE_TYPE = 9
GT_TOUCH_PRESSANDTAP: win32more.Windows.Win32.Graphics.Dwm.GESTURE_TYPE = 10
class MilMatrix3x2D(Structure):
    S_11: Double
    S_12: Double
    S_21: Double
    S_22: Double
    DX: Double
    DY: Double
    _pack_ = 1
class UNSIGNED_RATIO(Structure):
    uiNumerator: UInt32
    uiDenominator: UInt32
    _pack_ = 1


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Foundation
import win32more.Windows.Media.Capture
import win32more.Windows.Media.Capture.Core
import win32more.Windows.Win32.System.WinRT
class IVariablePhotoCapturedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Capture.Core.IVariablePhotoCapturedEventArgs'
    _iid_ = Guid('{d1eb4c5c-1b53-4e4a-8b5c-db7887ac949b}')
    @winrt_commethod(6)
    def get_Frame(self) -> win32more.Windows.Media.Capture.CapturedFrame: ...
    @winrt_commethod(7)
    def get_CaptureTimeOffset(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(8)
    def get_UsedFrameControllerIndex(self) -> win32more.Windows.Foundation.IReference[UInt32]: ...
    @winrt_commethod(9)
    def get_CapturedFrameControlValues(self) -> win32more.Windows.Media.Capture.CapturedFrameControlValues: ...
    CaptureTimeOffset = property(get_CaptureTimeOffset, None)
    CapturedFrameControlValues = property(get_CapturedFrameControlValues, None)
    Frame = property(get_Frame, None)
    UsedFrameControllerIndex = property(get_UsedFrameControllerIndex, None)
class IVariablePhotoSequenceCapture(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Capture.Core.IVariablePhotoSequenceCapture'
    _iid_ = Guid('{d0112d1d-031e-4041-a6d6-bd742476a8ee}')
    @winrt_commethod(6)
    def StartAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(7)
    def StopAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(8)
    def FinishAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(9)
    def add_PhotoCaptured(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.Capture.Core.VariablePhotoSequenceCapture, win32more.Windows.Media.Capture.Core.VariablePhotoCapturedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(10)
    def remove_PhotoCaptured(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(11)
    def add_Stopped(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.Capture.Core.VariablePhotoSequenceCapture, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(12)
    def remove_Stopped(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    PhotoCaptured = event()
    Stopped = event()
class IVariablePhotoSequenceCapture2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Capture.Core.IVariablePhotoSequenceCapture2'
    _iid_ = Guid('{fe2c62bc-50b0-43e3-917c-e3b92798942f}')
    @winrt_commethod(6)
    def UpdateSettingsAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
class VariablePhotoCapturedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.Capture.Core.IVariablePhotoCapturedEventArgs
    _classid_ = 'Windows.Media.Capture.Core.VariablePhotoCapturedEventArgs'
    @winrt_mixinmethod
    def get_Frame(self: win32more.Windows.Media.Capture.Core.IVariablePhotoCapturedEventArgs) -> win32more.Windows.Media.Capture.CapturedFrame: ...
    @winrt_mixinmethod
    def get_CaptureTimeOffset(self: win32more.Windows.Media.Capture.Core.IVariablePhotoCapturedEventArgs) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_mixinmethod
    def get_UsedFrameControllerIndex(self: win32more.Windows.Media.Capture.Core.IVariablePhotoCapturedEventArgs) -> win32more.Windows.Foundation.IReference[UInt32]: ...
    @winrt_mixinmethod
    def get_CapturedFrameControlValues(self: win32more.Windows.Media.Capture.Core.IVariablePhotoCapturedEventArgs) -> win32more.Windows.Media.Capture.CapturedFrameControlValues: ...
    CaptureTimeOffset = property(get_CaptureTimeOffset, None)
    CapturedFrameControlValues = property(get_CapturedFrameControlValues, None)
    Frame = property(get_Frame, None)
    UsedFrameControllerIndex = property(get_UsedFrameControllerIndex, None)
class VariablePhotoSequenceCapture(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.Capture.Core.IVariablePhotoSequenceCapture
    _classid_ = 'Windows.Media.Capture.Core.VariablePhotoSequenceCapture'
    @winrt_mixinmethod
    def StartAsync(self: win32more.Windows.Media.Capture.Core.IVariablePhotoSequenceCapture) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def StopAsync(self: win32more.Windows.Media.Capture.Core.IVariablePhotoSequenceCapture) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def FinishAsync(self: win32more.Windows.Media.Capture.Core.IVariablePhotoSequenceCapture) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def add_PhotoCaptured(self: win32more.Windows.Media.Capture.Core.IVariablePhotoSequenceCapture, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.Capture.Core.VariablePhotoSequenceCapture, win32more.Windows.Media.Capture.Core.VariablePhotoCapturedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_PhotoCaptured(self: win32more.Windows.Media.Capture.Core.IVariablePhotoSequenceCapture, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_Stopped(self: win32more.Windows.Media.Capture.Core.IVariablePhotoSequenceCapture, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.Capture.Core.VariablePhotoSequenceCapture, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Stopped(self: win32more.Windows.Media.Capture.Core.IVariablePhotoSequenceCapture, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def UpdateSettingsAsync(self: win32more.Windows.Media.Capture.Core.IVariablePhotoSequenceCapture2) -> win32more.Windows.Foundation.IAsyncAction: ...
    PhotoCaptured = event()
    Stopped = event()


make_ready(__name__)
